@@ -6,15 +6,14 @@
  * Date        : 2013-02-12
  * Description : Table view column helpers
  *
- * SPDX-FileCopyrightText: 2017-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2017-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2013      by Michael G. Hansen <mike at mghansen dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_TABLE_VIEW_COLUMNS_H
-#define DIGIKAM_TABLE_VIEW_COLUMNS_H
+#pragma once
 
 // Local includes
 
@@ -25,5 +24,3 @@
 #include "tableview_column_item.h"
 #include "tableview_column_photo.h"
 #include "tableview_column_thumbnail.h"
-
-#endif // DIGIKAM_TABLE_VIEW_COLUMNS_H
