@@ -6,14 +6,13 @@
  * Date        : 2008-11-28
  * Description : PNG image Converter batch tool.
  *
- * SPDX-FileCopyrightText: 2008-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2008-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_BQM_CONVERT_TO_PNG_H
-#define DIGIKAM_BQM_CONVERT_TO_PNG_H
+#pragma once
 
 // Local includes
 
@@ -31,7 +30,7 @@ class ConvertToPNG : public BatchTool
 public:
 
     explicit ConvertToPNG(QObject* const parent = nullptr);
-    ~ConvertToPNG()                                         override;
+    ~ConvertToPNG()                                         override = default;
 
     QString outputSuffix()                            const override;
     BatchToolSettings defaultSettings()                     override;
@@ -51,9 +50,7 @@ private:
 
 private:
 
-    bool m_changeSettings;
+    bool m_changeSettings = true;
 };
 
 } // namespace DigikamBqmConvertToPngPlugin
-
-#endif // DIGIKAM_BQM_CONVERT_TO_PNG_H
