@@ -6,7 +6,7 @@
  * Date        : 2018-07-30
  * Description : a BQM plugin to run user script.
  *
- * SPDX-FileCopyrightText: 2018-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2018-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -37,10 +37,6 @@ UserScriptPlugin::UserScriptPlugin(QObject* const parent)
 {
 }
 
-UserScriptPlugin::~UserScriptPlugin()
-{
-}
-
 QString UserScriptPlugin::name() const
 {
     return i18nc("@title", "User Shell Script");
@@ -99,3 +95,5 @@ void UserScriptPlugin::setup(QObject* const parent)
 }
 
 } // namespace DigikamBqmUserScriptPlugin
+
+#include "moc_userscriptplugin.cpp"
