@@ -6,14 +6,13 @@
  * Date        : 2018-07-30
  * Description : a BQM plugin to reduce red eyes
  *
- * SPDX-FileCopyrightText: 2018-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2018-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_RED_EYE_CORRECTION_PLUGIN_H
-#define DIGIKAM_RED_EYE_CORRECTION_PLUGIN_H
+#pragma once
 
 // Local includes
 
@@ -35,7 +34,7 @@ class RedEyeCorrectionPlugin : public DPluginBqm
 public:
 
     explicit RedEyeCorrectionPlugin(QObject* const parent = nullptr);
-    ~RedEyeCorrectionPlugin()            override;
+    ~RedEyeCorrectionPlugin()            override = default;
 
     QString name()                 const override;
     QString iid()                  const override;
@@ -51,5 +50,3 @@ public:
 };
 
 } // namespace DigikamBqmRedEyeCorrectionPlugin
-
-#endif // DIGIKAM_RED_EYE_CORRECTION_PLUGIN_H
