@@ -6,59 +6,13 @@
  * Date        : 2006-06-14
  * Description : A JPEG-2000 IO file for DImg framework- load operations
  *
- * Copyright (C) 2006-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#include "dimgjpeg2000loader.h"
-
-// Qt includes
-
-#include <QFile>
-#include <QByteArray>
-#include <QTextStream>
-#include <QScopedPointer>
-
-// Local includes
-
-#include "dimg.h"
-#include "digikam_debug.h"
-#include "digikam_config.h"
-#include "dimgloaderobserver.h"
-#include "dmetadata.h"
-
-// Jasper includes
-
-#ifndef Q_CC_MSVC
-extern "C"
-{
-#endif
-
-#if defined(Q_OS_DARWIN) && defined(Q_CC_CLANG)
-#   pragma clang diagnostic push
-#   pragma clang diagnostic ignored "-Wshift-negative-value"
-#endif
-
-#include <jasper/jasper.h>
-
-#if defined(Q_OS_DARWIN) && defined(Q_CC_CLANG)
-#   pragma clang diagnostic pop
-#endif
-
-#ifndef Q_CC_MSVC
-}
-#endif
+#include "dimgjpeg2000loader_p.h"
 
 namespace DigikamJPEG2000DImgPlugin
 {
@@ -67,6 +21,10 @@ bool DImgJPEG2000Loader::load(const QString& filePath, DImgLoaderObserver* const
 {
     readMetadata(filePath);
 
+#ifndef __clang_analyzer__
+
+    // Disable false-positive memory leak reported by scan-build with file stream.
+
 #ifdef Q_OS_WIN
 
     FILE* const file = _wfopen((const wchar_t*)filePath.utf16(), L"rb");
@@ -87,41 +45,54 @@ bool DImgJPEG2000Loader::load(const QString& filePath, DImgLoaderObserver* const
 
     imageSetAttribute(QLatin1String("format"), QLatin1String("JP2"));
 
+#if defined JAS_VERSION_MAJOR && JAS_VERSION_MAJOR >= 3
+
+    // NOTE: nothing to do.
+
+#else
+
+    QScopedPointer<DMetadata> metadata(new DMetadata(filePath));
+    QSize size             = metadata->getItemDimensions();
+    QString decoderOptions = QLatin1String("max_samples=100000000");
+
+    if (size.isValid())
+    {
+        imageWidth()   = size.width();
+        imageHeight()  = size.height();
+        decoderOptions = QString::fromLatin1("max_samples=%1").arg(size.width() * size.height() * 4);
+        qCDebug(DIGIKAM_DIMG_LOG_JP2K) << "JP2 image size:" << size;
+    }
+
     if (!(m_loadFlags & LoadImageData) && !(m_loadFlags & LoadICCData))
     {
         // libjasper will load the full image in memory already when calling jas_image_decode.
         // This is bad when scanning. See bugs 215458 and 195583.
-        // FIXME: Use Exiv2 to extract this info
+        // Exiv2 is used to extract this info.
 
         fclose(file);
 
-        QScopedPointer<DMetadata> metadata(new DMetadata(filePath));
-        QSize size = metadata->getItemDimensions();
-
-        if (size.isValid())
-        {
-            imageWidth()  = size.width();
-            imageHeight() = size.height();
-        }
-
         return true;
     }
 
+#endif
+
     // -------------------------------------------------------------------
     // Initialize JPEG 2000 API.
 
-    long  i, x, y;
-    int            components[4];
-    unsigned int   maximum_component_depth, scale[4], x_step[4], y_step[4];
-    unsigned long  number_components;
+    long           i                       = 0;
+    long           x                       = 0;
+    long           y                       = 0;
+    int            components[4]           = { 0 };
+    unsigned int   maximum_component_depth = 0;
+    unsigned int   scale[4]                = { 0 };
+    unsigned int   x_step[4]               = { 0 };
+    unsigned int   y_step[4]               = { 0 };
+    unsigned long  number_components       = 0;
+    jas_image_t*  jp2_image                = nullptr;
+    jas_stream_t* jp2_stream               = nullptr;
+    jas_matrix_t* pixels[4]                = { nullptr };
 
-    jas_image_t*  jp2_image   = nullptr;
-    jas_stream_t* jp2_stream  = nullptr;
-    jas_matrix_t* pixels[4];
-
-    int init = jas_init();
-
-    if (init != 0)
+    if (initJasper() != 0)
     {
         qCWarning(DIGIKAM_DIMG_LOG_JP2K) << "Unable to init JPEG2000 decoder";
         loadingFailed();
@@ -135,19 +106,39 @@ bool DImgJPEG2000Loader::load(const QString& filePath, DImgLoaderObserver* const
     if (jp2_stream == nullptr)
     {
         qCWarning(DIGIKAM_DIMG_LOG_JP2K) << "Unable to open JPEG2000 stream";
-        loadingFailed();
         fclose(file);
 
+        cleanupJasper();
+        loadingFailed();
+
         return false;
     }
 
+    // NOTE: at this point, libjasper takes owner to the file descriptor and it's no need to
+    // call fclose() anymore else a double free corruption appears.
+
     int fmt   = jas_image_strtofmt(QByteArray("jp2").data());
+
+#if defined JAS_VERSION_MAJOR && JAS_VERSION_MAJOR >= 3
+
     jp2_image = jas_image_decode(jp2_stream, fmt, nullptr);
 
+#else
+
+    // See bug 447240 and UPSTREAM https://github.com/jasper-software/jasper/issues/315#issuecomment-1007872809
+
+    qCDebug(DIGIKAM_DIMG_LOG_JP2K) << "jas_image_decode decoder options string:" << decoderOptions;
+
+    jp2_image = jas_image_decode(jp2_stream, fmt, decoderOptions.toLatin1().data());
+
+#endif
+
     if (jp2_image == nullptr)
     {
         qCWarning(DIGIKAM_DIMG_LOG_JP2K) << "Unable to decode JPEG2000 image";
         jas_stream_close(jp2_stream);
+
+        cleanupJasper();
         loadingFailed();
 
         return false;
@@ -155,6 +146,8 @@ bool DImgJPEG2000Loader::load(const QString& filePath, DImgLoaderObserver* const
 
     jas_stream_close(jp2_stream);
 
+#endif // __clang_analyzer__
+
     // some pseudo-progress
 
     if (observer)
@@ -179,6 +172,8 @@ bool DImgJPEG2000Loader::load(const QString& filePath, DImgLoaderObserver* const
             {
                 qCWarning(DIGIKAM_DIMG_LOG_JP2K) << "Error parsing JPEG2000 image : Missing Image Channel";
                 jas_image_destroy(jp2_image);
+
+                cleanupJasper();
                 loadingFailed();
 
                 return false;
@@ -194,6 +189,7 @@ bool DImgJPEG2000Loader::load(const QString& filePath, DImgLoaderObserver* const
             }
 
             colorModel = DImg::RGB;
+
             break;
         }
 
@@ -206,6 +202,8 @@ bool DImgJPEG2000Loader::load(const QString& filePath, DImgLoaderObserver* const
             {
                 qCWarning(DIGIKAM_DIMG_LOG_JP2K) << "Error parsing JP2000 image : Missing Image Channel";
                 jas_image_destroy(jp2_image);
+
+                cleanupJasper();
                 loadingFailed();
 
                 return false;
@@ -213,6 +211,7 @@ bool DImgJPEG2000Loader::load(const QString& filePath, DImgLoaderObserver* const
 
             number_components = 1;
             colorModel        = DImg::GRAYSCALE;
+
             break;
         }
 
@@ -227,6 +226,8 @@ bool DImgJPEG2000Loader::load(const QString& filePath, DImgLoaderObserver* const
             {
                 qCWarning(DIGIKAM_DIMG_LOG_JP2K) << "Error parsing JP2000 image : Missing Image Channel";
                 jas_image_destroy(jp2_image);
+
+                cleanupJasper();
                 loadingFailed();
 
                 return false;
@@ -241,9 +242,10 @@ bool DImgJPEG2000Loader::load(const QString& filePath, DImgLoaderObserver* const
                 ++number_components;
             }
 
-            // FIXME: image->colorspace=YCbCrColorspace;
+            // FIXME: image->colorspace = YCbCrColorspace;
 
             colorModel = DImg::YCBCR;
+
             break;
         }
 
@@ -251,6 +253,8 @@ bool DImgJPEG2000Loader::load(const QString& filePath, DImgLoaderObserver* const
         {
             qCWarning(DIGIKAM_DIMG_LOG_JP2K) << "Error parsing JP2000 image : Colorspace Model Is Not Supported";
             jas_image_destroy(jp2_image);
+
+            cleanupJasper();
             loadingFailed();
 
             return false;
@@ -265,16 +269,24 @@ bool DImgJPEG2000Loader::load(const QString& filePath, DImgLoaderObserver* const
 
     for (i = 0 ; i < (long)number_components ; ++i)
     {
-        if ((((jas_image_cmptwidth(jp2_image, components[i])*
-               jas_image_cmpthstep(jp2_image, components[i])) != (long)imageWidth()))  ||
-            (((jas_image_cmptheight(jp2_image, components[i])*
-               jas_image_cmptvstep(jp2_image, components[i])) != (long)imageHeight())) ||
+        if (
+            (
+             ((jas_image_cmptwidth(jp2_image, components[i])*
+               jas_image_cmpthstep(jp2_image, components[i])) != (long)imageWidth())
+            )  ||
+            (
+             ((jas_image_cmptheight(jp2_image, components[i])*
+               jas_image_cmptvstep(jp2_image, components[i])) != (long)imageHeight())
+            ) ||
             (jas_image_cmpttlx(jp2_image, components[i])  != 0)                        ||
             (jas_image_cmpttly(jp2_image, components[i])  != 0)                        ||
-            (jas_image_cmptsgnd(jp2_image, components[i]) != false))
+            (jas_image_cmptsgnd(jp2_image, components[i]) != false)
+           )
         {
             qCWarning(DIGIKAM_DIMG_LOG_JP2K) << "Error parsing JPEG2000 image : Irregular Channel Geometry Not Supported";
             jas_image_destroy(jp2_image);
+
+            cleanupJasper();
             loadingFailed();
 
             return false;
@@ -300,12 +312,30 @@ bool DImgJPEG2000Loader::load(const QString& filePath, DImgLoaderObserver* const
         {
             qCWarning(DIGIKAM_DIMG_LOG_JP2K) << "Error decoding JPEG2000 image data : Memory Allocation Failed";
             jas_image_destroy(jp2_image);
+
+            cleanupJasper();
             loadingFailed();
 
             return false;
         }
     }
 
+#if defined JAS_VERSION_MAJOR && JAS_VERSION_MAJOR >= 3
+
+    if (!(m_loadFlags & LoadImageData) && !(m_loadFlags & LoadICCData))
+    {
+        imageSetAttribute(QLatin1String("originalColorModel"), colorModel);
+        imageSetAttribute(QLatin1String("originalBitDepth"),   maximum_component_depth);
+        imageSetAttribute(QLatin1String("originalSize"),       QSize(imageWidth(), imageHeight()));
+
+        jas_image_destroy(jp2_image);
+        cleanupJasper();
+
+        return true;
+    }
+
+#endif
+
     if (maximum_component_depth > 8)
     {
         m_sixteenBit = true;
@@ -316,7 +346,7 @@ bool DImgJPEG2000Loader::load(const QString& filePath, DImgLoaderObserver* const
         scale[i] = 1;
         int prec = jas_image_cmptprec(jp2_image, components[i]);
 
-        if (m_sixteenBit && prec < 16)
+        if (m_sixteenBit && (prec < 16))
         {
             scale[i] = (1 << (16 - jas_image_cmptprec(jp2_image, components[i])));
         }
@@ -348,7 +378,7 @@ bool DImgJPEG2000Loader::load(const QString& filePath, DImgLoaderObserver* const
                 jas_matrix_destroy(pixels[i]);
             }
 
-            jas_cleanup();
+            cleanupJasper();
             loadingFailed();
 
             return false;
@@ -377,7 +407,7 @@ bool DImgJPEG2000Loader::load(const QString& filePath, DImgLoaderObserver* const
                         jas_matrix_destroy(pixels[i]);
                     }
 
-                    jas_cleanup();
+                    cleanupJasper();
                     loadingFailed();
 
                     return false;
@@ -493,9 +523,9 @@ bool DImgJPEG2000Loader::load(const QString& filePath, DImgLoaderObserver* const
                 }
             }
 
-            // use 0-10% and 90-100% for pseudo-progress
+            // Use 0-10% and 90-100% for pseudo-progress
 
-            if (observer && y >= (long)checkPoint)
+            if (observer && (y >= (long)checkPoint))
             {
                 checkPoint += granularity(observer, y, 0.8F);
 
@@ -508,8 +538,7 @@ bool DImgJPEG2000Loader::load(const QString& filePath, DImgLoaderObserver* const
                         jas_matrix_destroy(pixels[i]);
                     }
 
-                    jas_cleanup();
-
+                    cleanupJasper();
                     loadingFailed();
 
                     return false;
@@ -530,6 +559,7 @@ bool DImgJPEG2000Loader::load(const QString& filePath, DImgLoaderObserver* const
         jas_cmprof_t*  cm_profile  = nullptr;
 
         // To prevent cppcheck warnings.
+
         (void)icc_profile;
         (void)icc_stream;
         (void)cm_profile;
@@ -551,7 +581,7 @@ bool DImgJPEG2000Loader::load(const QString& filePath, DImgLoaderObserver* const
                 {
                     if (jas_stream_flush(icc_stream) == 0)
                     {
-                        jas_stream_memobj_t* const blob = (jas_stream_memobj_t*) icc_stream->obj_;
+                        jas_stream_memobj_t* const blob = reinterpret_cast<jas_stream_memobj_t*>(icc_stream->obj_);
                         QByteArray profile_rawdata;
                         profile_rawdata.resize(blob->len_);
                         memcpy(profile_rawdata.data(), blob->buf_, blob->len_);
@@ -575,7 +605,6 @@ bool DImgJPEG2000Loader::load(const QString& filePath, DImgLoaderObserver* const
     }
 
     imageData() = data.take();
-    imageSetAttribute(QLatin1String("format"),             QLatin1String("JP2"));
     imageSetAttribute(QLatin1String("originalColorModel"), colorModel);
     imageSetAttribute(QLatin1String("originalBitDepth"),   maximum_component_depth);
     imageSetAttribute(QLatin1String("originalSize"),       QSize(imageWidth(), imageHeight()));
@@ -587,7 +616,7 @@ bool DImgJPEG2000Loader::load(const QString& filePath, DImgLoaderObserver* const
         jas_matrix_destroy(pixels[i]);
     }
 
-    jas_cleanup();
+    cleanupJasper();
 
     return true;
 }
