@@ -6,14 +6,13 @@
  * Date        : 2006-10-18
  * Description : EXIF lens settings page.
  *
- * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_EXIF_LENS_H
-#define DIGIKAM_EXIF_LENS_H
+#pragma once
 
 // Qt includes
 
@@ -48,9 +47,7 @@ Q_SIGNALS:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamGenericMetadataEditPlugin
-
-#endif // DIGIKAM_EXIF_LENS_H
