@@ -6,7 +6,7 @@
  * Date        : 2006-10-13
  * Description : IPTC origin settings page.
  *
- * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -35,6 +35,7 @@
 
 // Local includes
 
+#include "digikam_globals.h"
 #include "dlayoutbox.h"
 #include "squeezedcombobox.h"
 #include "metadatacheckbox.h"
@@ -50,62 +51,38 @@ class Q_DECL_HIDDEN IPTCOrigin::Private
 {
 public:
 
-    explicit Private()
-      : dateCreatedCheck(nullptr),
-        dateDigitalizedCheck(nullptr),
-        timeCreatedCheck(nullptr),
-        timeDigitalizedCheck(nullptr),
-        syncEXIFDateCheck(nullptr),
-        cityCheck(nullptr),
-        sublocationCheck(nullptr),
-        provinceCheck(nullptr),
-        timeCreatedSel(nullptr),
-        timeDigitalizedSel(nullptr),
-        zoneCreatedSel(nullptr),
-        zoneDigitalizedSel(nullptr),
-        setTodayCreatedBtn(nullptr),
-        setTodayDigitalizedBtn(nullptr),
-        dateCreatedSel(nullptr),
-        dateDigitalizedSel(nullptr),
-        cityEdit(nullptr),
-        sublocationEdit(nullptr),
-        provinceEdit(nullptr),
-        locationEdit(nullptr),
-        countryCheck(nullptr),
-        countryCB(nullptr)
-    {
-    }
+    Private() = default;
 
-    QCheckBox*                     dateCreatedCheck;
-    QCheckBox*                     dateDigitalizedCheck;
-    QCheckBox*                     timeCreatedCheck;
-    QCheckBox*                     timeDigitalizedCheck;
-    QCheckBox*                     syncEXIFDateCheck;
-    QCheckBox*                     cityCheck;
-    QCheckBox*                     sublocationCheck;
-    QCheckBox*                     provinceCheck;
+    QCheckBox*                     dateCreatedCheck         = nullptr;
+    QCheckBox*                     dateDigitalizedCheck     = nullptr;
+    QCheckBox*                     timeCreatedCheck         = nullptr;
+    QCheckBox*                     timeDigitalizedCheck     = nullptr;
+    QCheckBox*                     syncEXIFDateCheck        = nullptr;
+    QCheckBox*                     cityCheck                = nullptr;
+    QCheckBox*                     sublocationCheck         = nullptr;
+    QCheckBox*                     provinceCheck            = nullptr;
 
-    QTimeEdit*                     timeCreatedSel;
-    QTimeEdit*                     timeDigitalizedSel;
+    QTimeEdit*                     timeCreatedSel           = nullptr;
+    QTimeEdit*                     timeDigitalizedSel       = nullptr;
 
-    TimeZoneComboBox*              zoneCreatedSel;
-    TimeZoneComboBox*              zoneDigitalizedSel;
+    TimeZoneComboBox*              zoneCreatedSel           = nullptr;
+    TimeZoneComboBox*              zoneDigitalizedSel       = nullptr;
 
-    QPushButton*                   setTodayCreatedBtn;
-    QPushButton*                   setTodayDigitalizedBtn;
+    QPushButton*                   setTodayCreatedBtn       = nullptr;
+    QPushButton*                   setTodayDigitalizedBtn   = nullptr;
 
-    QDateEdit*                     dateCreatedSel;
-    QDateEdit*                     dateDigitalizedSel;
+    QDateEdit*                     dateCreatedSel           = nullptr;
+    QDateEdit*                     dateDigitalizedSel       = nullptr;
 
-    QLineEdit*                     cityEdit;
-    QLineEdit*                     sublocationEdit;
-    QLineEdit*                     provinceEdit;
+    QLineEdit*                     cityEdit                 = nullptr;
+    QLineEdit*                     sublocationEdit          = nullptr;
+    QLineEdit*                     provinceEdit             = nullptr;
 
-    MultiValuesEdit*               locationEdit;
+    MultiValuesEdit*               locationEdit             = nullptr;
 
-    MetadataCheckBox*              countryCheck;
+    MetadataCheckBox*              countryCheck             = nullptr;
 
-    CountrySelector*               countryCB;
+    CountrySelector*               countryCB                = nullptr;
 };
 
 IPTCOrigin::IPTCOrigin(QWidget* const parent)
@@ -218,8 +195,8 @@ IPTCOrigin::IPTCOrigin(QWidget* const parent)
 
     // Remove 2 last items for the list (separator + Unknown item)
 
-    d->countryCB->removeItem(d->countryCB->count()-1);
-    d->countryCB->removeItem(d->countryCB->count()-1);
+    d->countryCB->removeItem(d->countryCB->count() - 1);
+    d->countryCB->removeItem(d->countryCB->count() - 1);
 
     QStringList list;
 
@@ -270,8 +247,7 @@ IPTCOrigin::IPTCOrigin(QWidget* const parent)
     grid->setColumnStretch(4, 10);
     grid->setRowStretch(13, 10);
 
-    int spacing = qMin(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing),
-                       QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
+    int spacing = layoutSpacing();
 
     grid->setContentsMargins(spacing, spacing, spacing, spacing);
     grid->setSpacing(spacing);
@@ -529,7 +505,7 @@ void IPTCOrigin::readMetadata(const DMetadata& meta)
 
     code = meta.getIptcTagsStringList("Iptc.Application2.LocationCode", false);
 
-    for (QStringList::Iterator it = code.begin(); it != code.end(); ++it)
+    for (QStringList::Iterator it = code.begin() ; it != code.end() ; ++it)
     {
         QStringList lst = d->locationEdit->getData();
         QStringList::Iterator it2;
