@@ -187,8 +187,9 @@ void TwTalker::link()
     // Discard the first line
 
     response = response.mid(response.indexOf('\n') + 1).trimmed();
+    const auto lines = response.split('\n');
 
-    Q_FOREACH (QString line, response.split('\n'))
+    for (QString line : lines)
     {
         int colon = line.indexOf(':');
         QString headerName = line.left(colon).trimmed();
@@ -291,8 +292,9 @@ void TwTalker::slotLinkingSucceeded()
         //Q_EMIT extraTokensReady(extraTokens);
 
         qCDebug(DIGIKAM_WEBSERVICES_LOG) << "Extra tokens in response:";
+        const auto keys = extraTokens.keys();
 
-        Q_FOREACH (const QString& key, extraTokens.keys())
+        for (const QString& key : keys)
         {
             qCDebug(DIGIKAM_WEBSERVICES_LOG) << "\t"
                                              << key
@@ -825,18 +827,18 @@ void TwTalker::parseResponseAddPhotoFinalize(const QByteArray& data)
 
     if (processingInfo != QJsonValue::Undefined)
     {
-        QString state = processingInfo.toObject()[QLatin1String("state")].toString();
+        const QString state = processingInfo.toObject().value(QLatin1String("state")).toString();
         qCDebug(DIGIKAM_WEBSERVICES_LOG) << "state: " << state;
 
         if (state == QLatin1String("pending"))
         {
-            QTimer::singleShot(processingInfo.toObject()[QLatin1String("check_after_secs")].toInt()*1000 /*msec*/,
+            QTimer::singleShot(processingInfo.toObject().value(QLatin1String("check_after_secs")).toInt() * 1000 /*msec*/,
                                this, SLOT(slotCheckUploadStatus()));
         }
     }
     else
     {
-        // We haven't Q_EMIT signalAddPhotoSucceeded() here yet, since we need to update the status first
+        // We haven't emit signalAddPhotoSucceeded() here yet, since we need to update the status first
 
         createTweet(d->mediaId);
     }
@@ -950,7 +952,7 @@ void TwTalker::parseResponseListFolders(const QByteArray& data)
     QList<QPair<QString, QString> > list;
     list.append(qMakePair(QLatin1String(""), QLatin1String("root")));
 
-    Q_FOREACH (const QJsonValue& value, jsonArray)
+    for (const QJsonValue& value : std::as_const(jsonArray))
     {
         QString path;
         QString folderName;
