@@ -6,24 +6,14 @@
  * Date        : 2012-01-24
  * Description : album parser progress indicator
  *
- * Copyright (C) 2012-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2019-2020 by Minh Nghia Duong <minhnghiaduong997 at gmail dot com>
+ * SPDX-FileCopyrightText: 2012-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2019-2020 by Minh Nghia Duong <minhnghiaduong997 at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_ALBUM_PARSER_H
-#define DIGIKAM_ALBUM_PARSER_H
+#pragma once
 
 // Local includes
 
@@ -41,12 +31,12 @@ class DIGIKAM_GUI_EXPORT AlbumParser : public ProgressItem
 public:
 
     /**
-     * Contructor to work on image list
+     * Constructor to work on image list
      */
     explicit AlbumParser(const ItemInfoList& infoList);
 
     /**
-     * Contructor to work on recursive mode from album
+     * Constructor to work on recursive mode from album
      */
     explicit AlbumParser(Album* const album);
 
@@ -70,9 +60,7 @@ private:
     AlbumParser(QObject*) = delete;
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_ALBUM_PARSER_H
