@@ -8,14 +8,13 @@
  *
  * SPDX-FileCopyrightText: 2009-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * SPDX-FileCopyrightText: 2010-2011 by Andi Clemens <andi dot clemens at gmail dot com>
- * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_ABSTRACT_COUNTING_ALBUM_TREE_VIEW_H
-#define DIGIKAM_ABSTRACT_COUNTING_ALBUM_TREE_VIEW_H
+#pragma once
 
 // Local includes
 
@@ -35,9 +34,9 @@ public:
 protected:
 
     void setAlbumModel(AbstractCountingAlbumModel* const model);
-    void setAlbumFilterModel(AlbumFilterModel* const filterModel);
+    virtual void setAlbumFilterModel(AlbumFilterModel* const filterModel)    override;
 
-    void rowsInserted(const QModelIndex& parent, int start, int end) override;
+    void rowsInserted(const QModelIndex& parent, int start, int end)         override;
 
 private Q_SLOTS:
 
@@ -52,5 +51,3 @@ private:
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_ABSTRACT_COUNTING_ALBUM_TREE_VIEW_H
