@@ -8,14 +8,13 @@
  *
  * SPDX-FileCopyrightText: 2009-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * SPDX-FileCopyrightText: 2010-2011 by Andi Clemens <andi dot clemens at gmail dot com>
- * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_DATE_TREE_VIEW_H
-#define DIGIKAM_DATE_TREE_VIEW_H
+#pragma once
 
 // Local includes
 
@@ -32,19 +31,17 @@ public:
 
     explicit DateTreeView(QWidget* const parent = nullptr, Flags flags = DefaultFlags);
 
-    DateAlbumModel* albumModel()                    const;
+    DateAlbumModel* dalbumModel()                   const;
     DAlbum* currentAlbum()                          const;
     DAlbum* albumForIndex(const QModelIndex& index) const;
 
-    void setAlbumModel(DateAlbumModel* const model);
-    void setAlbumFilterModel(AlbumFilterModel* const filterModel);
+    void setDAlbumModel(DateAlbumModel* const model);
+    void setAlbumFilterModel(AlbumFilterModel* const filterModel) override;
 
 public Q_SLOTS:
 
-    void setCurrentAlbums(const QList<Album*>& albums, bool selectInAlbumManager = true);
+    void setCurrentAlbums(const QList<Album*>& albums, bool selectInAlbumManager = true) override;
     void setCurrentAlbum(int dateId, bool selectInAlbumManager = true);
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_DATE_TREE_VIEW_H
