@@ -8,7 +8,7 @@
  *
  * SPDX-FileCopyrightText: 2016-2018 by Mario Frank <mario dot frank at uni minus potsdam dot de>
  * SPDX-FileCopyrightText: 2003      by Ricardo Niederberger Cabral <nieder at mail dot ru>
- * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2009-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * SPDX-FileCopyrightText: 2009-2011 by Andi Clemens <andi dot clemens at gmail dot com>
  *
@@ -19,6 +19,7 @@
 #include "haariface_p.h"
 
 #define ENABLE_DEBUG_DUPLICATES 0
+
 #if ENABLE_DEBUG_DUPLICATES
 #   define DEBUG_DUPLICATES(x) qCDebug(DIGIKAM_DATABASE_LOG) << x;
 #else
@@ -29,7 +30,7 @@ namespace Digikam
 {
 
 HaarIface::HaarIface()
-    : d(new Private())
+    : d(new Private)
 {
     qRegisterMetaType<DuplicatesResultsMap>("HaarIface::DuplicatesResultsMap");
 }
@@ -139,10 +140,12 @@ bool HaarIface::indexImage(qlonglong imageid)
 
     if (!info.isNull() && info.isVisible())
     {
+        QDateTime modDateTime = SimilarityDbAccess().backend()->asDBDateTime(info.modDateTime());
+
         SimilarityDbAccess().backend()->execSql(QString::fromUtf8("REPLACE INTO ImageHaarMatrix "
                                                                   " (imageid, modificationDate, uniqueHash, matrix) "
                                                                   " VALUES(?, ?, ?, ?);"),
-                                                imageid, info.modDateTime(), info.uniqueHash(), array);
+                                                imageid, modDateTime, info.uniqueHash(), array);
     }
 
     return true;
@@ -261,7 +264,7 @@ QMap<qlonglong, double> HaarIface::bestMatchesForSignature(const QString& signat
     return result;
 }
 
-QMultiMap<double, qlonglong> HaarIface::bestMatches(Haar::SignatureData* const querySig,
+QMultiMap<double, qlonglong> HaarIface::bestMatches(const Haar::SignatureData* const querySig,
                                                     int numberOfResults,
                                                     const QList<int>& targetAlbums,
                                                     SketchType type)
@@ -300,7 +303,7 @@ QMultiMap<double, qlonglong> HaarIface::bestMatches(Haar::SignatureData* const q
 
             // if the new entry has a higher score, put it in the list and remove that last one
 
-            if (score < worstScore)
+            if      (score < worstScore)
             {
                 bestMatches.erase(last);
                 bestMatches.insert(score, id);
@@ -447,9 +450,11 @@ bool HaarIface::fulfillsRestrictions(qlonglong imageId, int albumId,
     }
     else if (targetAlbums.isEmpty() || targetAlbums.contains(albumId))
     {
-        return ( searchResultRestriction == None)                                            ||
-               ((searchResultRestriction == SameAlbum)      && (originalAlbumId == albumId)) ||
-               ((searchResultRestriction == DifferentAlbum) && (originalAlbumId != albumId));
+        return (
+                (searchResultRestriction == None)                                             ||
+                ((searchResultRestriction == SameAlbum)      && (originalAlbumId == albumId)) ||
+                ((searchResultRestriction == DifferentAlbum) && (originalAlbumId != albumId))
+               ) ;
     }
     else
     {
@@ -457,7 +462,7 @@ bool HaarIface::fulfillsRestrictions(qlonglong imageId, int albumId,
     }
 }
 
-QMap<qlonglong, double> HaarIface::searchDatabase(Haar::SignatureData* const querySig,
+QMap<qlonglong, double> HaarIface::searchDatabase(const Haar::SignatureData* const querySig,
                                                   SketchType type, const QList<int>& targetAlbums,
                                                   DuplicatesSearchRestrictions searchResultRestriction,
                                                   qlonglong originalImageId,
@@ -473,7 +478,7 @@ QMap<qlonglong, double> HaarIface::searchDatabase(Haar::SignatureData* const que
     queryMapY.fill(querySig->sig[0]);
     queryMapI.fill(querySig->sig[1]);
     queryMapQ.fill(querySig->sig[2]);
-    std::reference_wrapper<Haar::SignatureMap> queryMaps[3] = { queryMapY, queryMapI, queryMapQ };
+    const std::reference_wrapper<Haar::SignatureMap> queryMaps[3] = { queryMapY, queryMapI, queryMapQ };
 
     // Map imageid -> score. Lowest score is best.
     // any newly inserted value will be initialized with a score of 0, as required
@@ -670,7 +675,7 @@ QSet<qlonglong> HaarIface::imagesFromAlbumsAndTags(const QList<int>& albums2Scan
 
     // Get all items DB id from all albums and all collections
 
-    Q_FOREACH (int albumId, albums2Scan)
+    for (int albumId : std::as_const(albums2Scan))
     {
         const auto list = CoreDbAccess().db()->getItemIDsInAlbum(albumId);
         imagesFromAlbums.unite(QSet<qlonglong>(list.begin(), list.end()));
@@ -678,7 +683,7 @@ QSet<qlonglong> HaarIface::imagesFromAlbumsAndTags(const QList<int>& albums2Scan
 
     // Get all items DB id from all tags
 
-    Q_FOREACH (int albumId, tags2Scan)
+    for (int albumId : std::as_const(tags2Scan))
     {
         const auto list = CoreDbAccess().db()->getItemIDsInTag(albumId);
         imagesFromTags.unite(QSet<qlonglong>(list.begin(), list.end()));
@@ -818,7 +823,11 @@ HaarIface::DuplicatesResultsMap HaarIface::findDuplicates(const QSet<qlonglong>&
 
             // the list will usually contain one image: the original. Filter out.
 
-            if (!(duplicates.isEmpty()) && !((duplicates.count() == 1) && (duplicates.first() == *images2ScanIterator)))
+            if (
+                !(duplicates.isEmpty())     &&
+                !((duplicates.count() == 1) &&
+                (duplicates.first() == *images2ScanIterator))
+               )
             {
                 DEBUG_DUPLICATES("\tHas duplicates");
 
@@ -831,8 +840,10 @@ HaarIface::DuplicatesResultsMap HaarIface::findDuplicates(const QSet<qlonglong>&
                 qlonglong refFileSize   = 0;
                 qlonglong reference     = *images2ScanIterator;
 
-                const bool useReferenceImages = ((refImageSelectionMethod == RefImageSelMethod::PreferFolder) ||
-                                                 (refImageSelectionMethod == RefImageSelMethod::ExcludeFolder));
+                const bool useReferenceImages = (
+                                                 (refImageSelectionMethod == RefImageSelMethod::PreferFolder) ||
+                                                 (refImageSelectionMethod == RefImageSelMethod::ExcludeFolder)
+                                                );
 
                 bool referenceFound = false;
 
@@ -864,13 +875,15 @@ HaarIface::DuplicatesResultsMap HaarIface::findDuplicates(const QSet<qlonglong>&
                     }
                 }
 
-                if (!useReferenceImages                                                               ||
+                if (
+                    !useReferenceImages                                                               ||
                     (!referenceFound && (refImageSelectionMethod == RefImageSelMethod::PreferFolder)) ||
-                    (referenceFound  && (refImageSelectionMethod == RefImageSelMethod::ExcludeFolder)))
+                    (referenceFound  && (refImageSelectionMethod == RefImageSelMethod::ExcludeFolder))
+                   )
                 {
                     DEBUG_DUPLICATES("\tChecking Duplicates")
 
-                    Q_FOREACH (const qlonglong& refId, duplicates)
+                    for (const qlonglong& refId : std::as_const(duplicates))
                     {
 
 #if ENABLE_DEBUG_DUPLICATES
@@ -915,22 +928,36 @@ HaarIface::DuplicatesResultsMap HaarIface::findDuplicates(const QSet<qlonglong>&
                             }
                         }
 
-                        const bool preferFolderCond  = (referenceFound && (refImageSelectionMethod == RefImageSelMethod::PreferFolder));
+                        const bool preferFolderCond  = (
+                                                        referenceFound &&
+                                                        (refImageSelectionMethod == RefImageSelMethod::PreferFolder)
+                                                       );
 
-                        const bool excludeFolderCond = (!referenceFound && (refImageSelectionMethod == RefImageSelMethod::ExcludeFolder));
+                        const bool excludeFolderCond = (
+                                                        !referenceFound &&
+                                                        (refImageSelectionMethod == RefImageSelMethod::ExcludeFolder)
+                                                       );
 
-                        const bool newerCreationCond = ((refImageSelectionMethod == RefImageSelMethod::NewerCreationDate) &&
-                                                        (!refDateTime.isValid() || (info.dateTime() >  refDateTime)));
+                        const bool newerCreationCond = (
+                                                        (refImageSelectionMethod == RefImageSelMethod::NewerCreationDate) &&
+                                                        (!refDateTime.isValid() || (info.dateTime() >  refDateTime))
+                                                       );
 
-                        const bool newerModCond      = ((refImageSelectionMethod == RefImageSelMethod::NewerModificationDate) &&
-                                                        (!refModDateTime.isValid() || (info.modDateTime() >  refModDateTime)));
+                        const bool newerModCond      = (
+                                                        (refImageSelectionMethod == RefImageSelMethod::NewerModificationDate) &&
+                                                        (!refModDateTime.isValid() || (info.modDateTime() >  refModDateTime))
+                                                       );
 
-                        const bool olderOrLargerCond = ((refImageSelectionMethod == RefImageSelMethod::OlderOrLarger)          &&
+                        const bool olderOrLargerCond = (
+                                                        (refImageSelectionMethod == RefImageSelMethod::OlderOrLarger)          &&
                                                         (!refDateTime.isValid()                                                ||
                                                         (infoPixelSize   >  refPixelSize)                                      ||
                                                         ((infoPixelSize  == refPixelSize) && (info.fileSize() >  refFileSize)) ||
-                                                        ((infoPixelSize  == refPixelSize) && (info.fileSize() == refFileSize)  &&
-                                                        (info.dateTime() <  refDateTime))));
+                                                        (
+                                                         (infoPixelSize  == refPixelSize) && (info.fileSize() == refFileSize)  &&
+                                                         (info.dateTime() <  refDateTime))
+                                                        )
+                                                       );
 
                         if (preferFolderCond || excludeFolderCond || newerCreationCond || newerModCond || olderOrLargerCond)
                         {
@@ -976,9 +1003,15 @@ HaarIface::DuplicatesResultsMap HaarIface::findDuplicates(const QSet<qlonglong>&
 
         if (observer)
         {
-            observer->imageProcessed();
+            ItemInfo info(*images2ScanIterator);
+            observer->imageProcessed(
+                                     info,
+                                     QImage(),              // See bug 496691: performance issue - do not forward a loaded preview.
+                                     duplicates.count()
+                                    );
         }
     }
+
 #if ENABLE_DEBUG_DUPLICATES
 
     DEBUG_DUPLICATES("Results:");
@@ -999,7 +1032,7 @@ HaarIface::DuplicatesResultsMap HaarIface::findDuplicates(const QSet<qlonglong>&
 double HaarIface::calculateScore(const Haar::SignatureData& querySig,
                                  const Haar::SignatureData& targetSig,
                                  const Haar::Weights& weights,
-                                 std::reference_wrapper<Haar::SignatureMap>* const queryMaps)
+                                 const std::reference_wrapper<Haar::SignatureMap>* const queryMaps)
 {
     double score = 0.0;
 
