@@ -8,7 +8,7 @@
  *
  * SPDX-FileCopyrightText: 2016-2018 by Mario Frank <mario dot frank at uni minus potsdam dot de>
  * SPDX-FileCopyrightText: 2003      by Ricardo Niederberger Cabral <nieder at mail dot ru>
- * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2009-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * SPDX-FileCopyrightText: 2009-2011 by Andi Clemens <andi dot clemens at gmail dot com>
  *
@@ -16,8 +16,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_HAAR_IFACE_P_H
-#define DIGIKAM_HAAR_IFACE_P_H
+#pragma once
 
 #include "haariface.h"
 
@@ -39,6 +38,7 @@
 // Local includes
 
 #include "digikam_debug.h"
+#include "digikam_globals_p.h"
 #include "jpegutils.h"
 #include "dimg.h"
 #include "iteminfo.h"
@@ -62,7 +62,7 @@ typedef QMap<qlonglong, Haar::SignatureData> SignatureCache;
 typedef QMap<qlonglong, int>                 AlbumCache;
 
 /**
- * This class encapsulates the Haar signature in a QByteArray
+ * @brief This class encapsulates the Haar signature in a QByteArray
  * that can be stored as a BLOB in the database.
  *
  * Reading and writing is done in a platform-independent manner, which
@@ -82,11 +82,11 @@ public:
     DatabaseBlob() = default;
 
     /**
-     * Read the QByteArray into the Haar::SignatureData.
+     * @brief Read the QByteArray into the Haar::SignatureData.
      */
     void read(const QByteArray& array, Haar::SignatureData& data);
 
-    QByteArray write(Haar::SignatureData& data);
+    QByteArray write(const Haar::SignatureData& data);
 };
 
 // -----------------------------------------------------------------------------------------------------
@@ -95,8 +95,8 @@ class Q_DECL_HIDDEN HaarIface::Private
 {
 public:
 
-    explicit Private();
-    ~Private();
+    Private();
+    ~Private() = default;
 
 public:
 
@@ -117,8 +117,8 @@ public:
 
 public:
 
-    const static QString            signatureQuery;
-    const static Haar::WeightBin    weightBin;
+    const QString                   signatureQuery = QString::fromUtf8("SELECT imageid, matrix FROM ImageHaarMatrix;");
+    const Haar::WeightBin           weightBin;
 
 private:
 
@@ -131,5 +131,3 @@ private:
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_HAAR_IFACE_P_H
