@@ -7,7 +7,7 @@
  * Description : Mysql internal database server
  *
  * SPDX-FileCopyrightText: 2009-2011 by Holger Foerster <Hamsi2k at freenet dot de>
- * SPDX-FileCopyrightText: 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2016      by Swati Lodha <swatilodha27 at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -18,9 +18,9 @@
 
 // Qt includes
 
+#include <QProgressDialog>
 #include <QStandardPaths>
 #include <QApplication>
-#include <QMessageBox>
 #include <QTcpServer>
 #include <QDateTime>
 #include <QFileInfo>
@@ -40,8 +40,6 @@
 
 #include "digikam_debug.h"
 #include "digikam_globals.h"
-#include "dbengineparameters.h"
-#include "databaseserverstarter.h"
 
 namespace Digikam
 {
@@ -50,26 +48,23 @@ class Q_DECL_HIDDEN DatabaseServer::Private
 {
 public:
 
-    explicit Private()
-        : databaseProcess(nullptr),
-          serverPort(3307)
-    {
-    }
+    Private() = default;
 
     DbEngineParameters     params;
-    QProcess*              databaseProcess;
+    QProcess*              databaseProcess = nullptr;
 
     QString                internalDBName;
+    QString                mysqlUpgradePath;
+    QString                mysqlServerPath;
     QString                mysqlAdminPath;
-    QString                mysqldInitPath;
-    QString                mysqldCmd;
+    QString                mysqlInitPath;
     QString                dataDir;
     QString                miscDir;
     QString                fileDataDir;
     QString                actualConfig;
     QString                globalConfig;
 
-    int                    serverPort;
+    int                    serverPort      = 3307;
 };
 
 DatabaseServer::DatabaseServer(const DbEngineParameters& params, DatabaseServerStarter* const parent)
@@ -80,7 +75,7 @@ DatabaseServer::DatabaseServer(const DbEngineParameters& params, DatabaseServerS
 
     qCDebug(DIGIKAM_DATABASESERVER_LOG) << d->params;
 
-    QString defaultAkDir = DbEngineParameters::internalServerPrivatePath();
+    QString defaultAkDir = DbEngineParameters::serverPrivatePath();
     QString dataDir;
 
     if (d->params.internalServerPath().isEmpty())
@@ -96,9 +91,10 @@ DatabaseServer::DatabaseServer(const DbEngineParameters& params, DatabaseServerS
     qCDebug(DIGIKAM_DATABASESERVER_LOG) << "Internal Server data path:" << dataDir;
 
     d->internalDBName       = QLatin1String("digikam");
+    d->mysqlUpgradePath     = d->params.internalServerMysqlUpgradeCmd;
+    d->mysqlServerPath      = d->params.internalServerMysqlServerCmd;
     d->mysqlAdminPath       = d->params.internalServerMysqlAdminCmd;
-    d->mysqldInitPath       = d->params.internalServerMysqlInitCmd;
-    d->mysqldCmd            = d->params.internalServerMysqlServCmd;
+    d->mysqlInitPath        = d->params.internalServerMysqlInitCmd;
     d->dataDir              = dataDir;
     d->miscDir              = QDir(defaultAkDir).absoluteFilePath(QLatin1String("db_misc"));
     d->fileDataDir          = QDir(defaultAkDir).absoluteFilePath(QLatin1String("file_db_data"));
@@ -136,6 +132,7 @@ void DatabaseServer::run()
     while (databaseServerStateEnum != stopped);
 
     qCDebug(DIGIKAM_DATABASESERVER_LOG) << "Shutting down database server";
+
     Q_EMIT done();
 }
 
@@ -153,7 +150,7 @@ DatabaseServerError DatabaseServer::startDatabaseProcess()
                                     i18n("Database type is not supported."));
     }
 
-    if     (error.getErrorType() == DatabaseServerError::StartError)
+    if      (error.getErrorType() == DatabaseServerError::StartError)
     {
         databaseServerStateEnum = notRunning;
     }
@@ -194,10 +191,13 @@ void DatabaseServer::stopDatabaseProcess()
 
     QProcess mysqlShutDownProcess;
     mysqlShutDownProcess.setProcessEnvironment(adjustedEnvironmentForAppImage());
+
+    qCDebug(DIGIKAM_DATABASESERVER_LOG) << "Send stop to database server";
+
     mysqlShutDownProcess.start(d->mysqlAdminPath, mysqlShutDownArgs);
     mysqlShutDownProcess.waitForFinished();
 
-    if ((d->databaseProcess->state() == QProcess::Running) && !d->databaseProcess->waitForFinished())
+    if (!d->databaseProcess->waitForFinished() && (d->databaseProcess->state() == QProcess::Running))
     {
         qCDebug(DIGIKAM_DATABASESERVER_LOG) << "Database process will be killed now";
         d->databaseProcess->kill();
@@ -237,7 +237,7 @@ DatabaseServerError DatabaseServer::startMysqlDatabaseProcess()
         return error;
     }
 
-    bool needUpgrade = checkAndRemoveMysqlLogs();
+    copyAndRemoveMysqlLogs();
 
     error = createMysqlFiles();
 
@@ -253,17 +253,21 @@ DatabaseServerError DatabaseServer::startMysqlDatabaseProcess()
         return error;
     }
 
-    if (needUpgrade)
-    {
-        error = upgradeMysqlDatabase();
+    error = initMysqlDatabase(false);
 
-        if (error.getErrorType() != DatabaseServerError::NoErrors)
-        {
-            return error;
-        }
+    if (error.getErrorType() != DatabaseServerError::NoErrors)
+    {
+        return error;
     }
 
-    error = initMysqlDatabase();
+    error = upgradeMysqlDatabase();
+
+    if (error.getErrorType() != DatabaseServerError::NoErrors)
+    {
+        return error;
+    }
+
+    error = initMysqlDatabase(true);
 
     if (error.getErrorType() != DatabaseServerError::NoErrors)
     {
@@ -277,9 +281,18 @@ DatabaseServerError DatabaseServer::startMysqlDatabaseProcess()
 
 DatabaseServerError DatabaseServer::checkDatabaseDirs() const
 {
-    DatabaseServerError result;
+    DatabaseServerError error;
 
-    if (d->mysqldCmd.isEmpty())
+    if (d->mysqlUpgradePath.isEmpty())
+    {
+        qCDebug(DIGIKAM_DATABASESERVER_LOG) << "No path to mysql upgrade command set in configuration file!";
+
+        return DatabaseServerError(DatabaseServerError::StartError,
+                                   i18n("No path to mysql upgrade command set "
+                                        "in configuration file."));
+    }
+
+    if (d->mysqlServerPath.isEmpty())
     {
         qCDebug(DIGIKAM_DATABASESERVER_LOG) << "No path to mysql server command set in configuration file!";
 
@@ -288,15 +301,6 @@ DatabaseServerError DatabaseServer::checkDatabaseDirs() const
                                         "in configuration file."));
     }
 
-    if (d->mysqldInitPath.isEmpty())
-    {
-        qCDebug(DIGIKAM_DATABASESERVER_LOG) << "No path to mysql initialization command set in configuration file!";
-
-        return DatabaseServerError(DatabaseServerError::StartError,
-                                   i18n("No path to mysql initialization "
-                                        "command set in configuration file."));
-    }
-
     if (d->mysqlAdminPath.isEmpty())
     {
         qCDebug(DIGIKAM_DATABASESERVER_LOG) << "No path to mysql administration command set in configuration file!";
@@ -306,6 +310,15 @@ DatabaseServerError DatabaseServer::checkDatabaseDirs() const
                                         "command set in configuration file."));
     }
 
+    if (d->mysqlInitPath.isEmpty())
+    {
+        qCDebug(DIGIKAM_DATABASESERVER_LOG) << "No path to mysql initialization command set in configuration file!";
+
+        return DatabaseServerError(DatabaseServerError::StartError,
+                                   i18n("No path to mysql initialization "
+                                        "command set in configuration file."));
+    }
+
     if (!QFile::exists(d->dataDir) && !QDir().mkpath(d->dataDir))
     {
         qCDebug(DIGIKAM_DATABASESERVER_LOG) << "Cannot create directory "
@@ -336,12 +349,12 @@ DatabaseServerError DatabaseServer::checkDatabaseDirs() const
                                         QDir::toNativeSeparators(d->fileDataDir)));
     }
 
-    return result;
+    return error;
 }
 
 DatabaseServerError DatabaseServer::initMysqlConfig() const
 {
-    DatabaseServerError result;
+    DatabaseServerError error;
 
     QString localConfig = QStandardPaths::locate(QStandardPaths::GenericDataLocation,
                                                  QLatin1String("digikam/database/mysql-local.conf"));
@@ -356,8 +369,10 @@ DatabaseServerError DatabaseServer::initMysqlConfig() const
         // If actual does not yet exist it was initialised with datetime 0
         // so it will get updated too
 
-        if ((QFileInfo(d->globalConfig).lastModified() > QFileInfo(actualFile).lastModified()) ||
-            (QFileInfo(localConfig).lastModified()     > QFileInfo(actualFile).lastModified()))
+        if (
+            (QFileInfo(d->globalConfig).lastModified() > QFileInfo(actualFile).lastModified()) ||
+            (QFileInfo(localConfig).lastModified()     > QFileInfo(actualFile).lastModified())
+           )
         {
             confShouldUpdate = true;
 
@@ -394,8 +409,10 @@ DatabaseServerError DatabaseServer::initMysqlConfig() const
         if      (confUpdate)
         {
             const QFile::Permissions allowedPerms = actualFile.permissions() &
-                                                    (QFile::ReadOwner | QFile::WriteOwner |
-                                                     QFile::ReadGroup | QFile::WriteGroup | QFile::ReadOther);
+                                                    (
+                                                     QFile::ReadOwner | QFile::WriteOwner |
+                                                     QFile::ReadGroup | QFile::WriteGroup | QFile::ReadOther
+                                                    );
 
             if (allowedPerms != actualFile.permissions())
             {
@@ -421,7 +438,7 @@ DatabaseServerError DatabaseServer::initMysqlConfig() const
                                     d->globalConfig,
                                     d->actualConfig);
 
-            return DatabaseServerError(DatabaseServerError::StartError, errorMsg);
+            error = DatabaseServerError(DatabaseServerError::StartError, errorMsg);
         }
         else
         {
@@ -433,35 +450,33 @@ DatabaseServerError DatabaseServer::initMysqlConfig() const
     {
         qCDebug(DIGIKAM_DATABASESERVER_LOG) << "Cannot find MySQL server default configuration (mysql-global.conf)";
 
-        return DatabaseServerError(DatabaseServerError::StartError,
-                                   i18n("Cannot find MySQL server default "
-                                        "configuration (mysql-global.conf)."));
+        error = DatabaseServerError(DatabaseServerError::StartError,
+                                    i18n("Cannot find MySQL server default "
+                                         "configuration (mysql-global.conf)."));
     }
 
-    return result;
+    return error;
 }
 
-bool DatabaseServer::checkAndRemoveMysqlLogs() const
+void DatabaseServer::copyAndRemoveMysqlLogs() const
 {
     // Move mysql error log file out of the way
 
-    const QFileInfo errorLog(d->dataDir,
-                             QLatin1String("mysql.err"));
-
-    bool needUpgrade = false;
+    const QFileInfo errorLog(d->dataDir, QLatin1String("mysql.err"));
 
     if (errorLog.exists())
     {
         QFile logFile(errorLog.absoluteFilePath());
         QFile oldLogFile(QDir(d->dataDir).absoluteFilePath(QLatin1String("mysql.err.old")));
 
+        if (oldLogFile.exists() && (oldLogFile.size() > (100 * 1024 * 1024)))
+        {
+            oldLogFile.remove();
+        }
+
         if (logFile.open(QFile::ReadOnly) && oldLogFile.open(QFile::Append))
         {
-            QByteArray runMaria("run mariadb-upgrade");
-            QByteArray runMysql("run mysql_upgrade");
             QByteArray ba = logFile.readAll();
-            needUpgrade   = (ba.contains(runMaria) || ba.contains(runMysql));
-
             oldLogFile.write(ba);
             oldLogFile.close();
             logFile.close();
@@ -472,23 +487,25 @@ bool DatabaseServer::checkAndRemoveMysqlLogs() const
             qCDebug(DIGIKAM_DATABASESERVER_LOG) << "Failed to open MySQL error log.";
         }
     }
-
-    // Clear mysql ib_logfile's in case innodb_log_file_size option changed in last confUpdate
-
-    //QFile(QDir(d->dataDir).absoluteFilePath(QLatin1String("ib_logfile0"))).remove();
-    //QFile(QDir(d->dataDir).absoluteFilePath(QLatin1String("ib_logfile1"))).remove();
-
-    return needUpgrade;
 }
 
 DatabaseServerError DatabaseServer::createMysqlFiles() const
 {
-    DatabaseServerError result;
+    DatabaseServerError error;
 
     // Initialize the database
 
     if (!QFile(QDir(d->dataDir).absoluteFilePath(QLatin1String("mysql"))).exists())
     {
+        QPointer<QProgressDialog> dialog = new QProgressDialog;
+        dialog->setLabelText(i18n("The internal MySQL database is "
+                                  "initializing, please wait..."));
+        dialog->setCancelButton(nullptr);
+        dialog->setMinimumDuration(2000);
+        dialog->setModal(true);
+        dialog->setMinimum(0);
+        dialog->setMaximum(0);
+
         // Synthesize the server initialization command line arguments
 
         QStringList mysqlInitCmdArgs;
@@ -512,37 +529,44 @@ DatabaseServerError DatabaseServer::createMysqlFiles() const
 
         QProcess initProcess;
         initProcess.setProcessEnvironment(adjustedEnvironmentForAppImage());
-        initProcess.start(d->mysqldInitPath, mysqlInitCmdArgs);
+        initProcess.start(d->mysqlInitPath, mysqlInitCmdArgs);
 
         qCDebug(DIGIKAM_DATABASESERVER_LOG) << "Database initializer:"
                                             << initProcess.program()
                                             << initProcess.arguments();
 
-        if (!initProcess.waitForFinished() || (initProcess.exitCode() != 0))
+        while (!initProcess.waitForFinished(250))
         {
-            return DatabaseServerError(DatabaseServerError::StartError,
-                                       processErrorLog(&initProcess,
-                                                       i18n("Could not start database initializer.")));
+            qApp->processEvents();
+        }
+
+        delete dialog;
+
+        if (initProcess.exitCode() != 0)
+        {
+            error = DatabaseServerError(DatabaseServerError::StartError,
+                                        processErrorLog(&initProcess,
+                                                        i18n("Could not start database initializer.")));
         }
     }
 
-    return result;
+    return error;
 }
 
 DatabaseServerError DatabaseServer::startMysqlServer()
 {
-    DatabaseServerError result;
+    DatabaseServerError error;
 
     // Synthesize the server command line arguments
 
-    QStringList mysqldCmdArgs;
-    mysqldCmdArgs << QDir::toNativeSeparators(QString::fromLatin1("--defaults-file=%1").arg(d->actualConfig))
-                  << QDir::toNativeSeparators(QString::fromLatin1("--datadir=%1").arg(d->dataDir));
+    QStringList mysqldServCmdArgs;
+    mysqldServCmdArgs << QDir::toNativeSeparators(QString::fromLatin1("--defaults-file=%1").arg(d->actualConfig))
+                      << QDir::toNativeSeparators(QString::fromLatin1("--datadir=%1").arg(d->dataDir));
 
 #ifdef Q_OS_MACOS
 
-    mysqldCmdArgs << QDir::toNativeSeparators(QString::fromLatin1("--basedir=%1/lib/mariadb/")
-                                              .arg(macOSBundlePrefix()));
+    mysqldServCmdArgs << QDir::toNativeSeparators(QString::fromLatin1("--basedir=%1/lib/mariadb/")
+                                                  .arg(macOSBundlePrefix()));
 
 #endif
 
@@ -557,18 +581,18 @@ DatabaseServerError DatabaseServer::startMysqlServer()
         server->listen(QHostAddress::LocalHost, 0);
         d->serverPort = server->serverPort();
 
-        qCWarning(DIGIKAM_DATABASESERVER_LOG) << "Now use the free port:"  << d->serverPort;
+        qCWarning(DIGIKAM_DATABASESERVER_LOG) << "Now use the free port:" << d->serverPort;
     }
 
     server->close();
     delete server;
 
-    mysqldCmdArgs << QLatin1String("--skip-networking=0")
-                  << QString::fromLatin1("--port=%1").arg(d->serverPort);
+    mysqldServCmdArgs << QLatin1String("--skip-networking=0")
+                      << QString::fromLatin1("--port=%1").arg(d->serverPort);
 
 #else
 
-    mysqldCmdArgs << QString::fromLatin1("--socket=%1/mysql.socket").arg(d->miscDir);
+    mysqldServCmdArgs << QString::fromLatin1("--socket=%1/mysql.socket").arg(d->miscDir);
 
 #endif
 
@@ -576,7 +600,7 @@ DatabaseServerError DatabaseServer::startMysqlServer()
 
     d->databaseProcess = new QProcess();
     d->databaseProcess->setProcessEnvironment(adjustedEnvironmentForAppImage());
-    d->databaseProcess->start(d->mysqldCmd, mysqldCmdArgs);
+    d->databaseProcess->start(d->mysqlServerPath, mysqldServCmdArgs);
 
     qCDebug(DIGIKAM_DATABASESERVER_LOG) << "Database server:"
                                         << d->databaseProcess->program()
@@ -590,15 +614,15 @@ DatabaseServerError DatabaseServer::startMysqlServer()
         delete d->databaseProcess;
         d->databaseProcess = nullptr;
 
-        return DatabaseServerError(DatabaseServerError::StartError, errorMsg);
+        error = DatabaseServerError(DatabaseServerError::StartError, errorMsg);
     }
 
-    return result;
+    return error;
 }
 
-DatabaseServerError DatabaseServer::initMysqlDatabase() const
+DatabaseServerError DatabaseServer::initMysqlDatabase(bool useDatabase) const
 {
-    DatabaseServerError result;
+    DatabaseServerError error;
 
     const QLatin1String initCon("initConnection");
 
@@ -652,7 +676,6 @@ DatabaseServerError DatabaseServer::initMysqlDatabase() const
 
         if (!opened)
         {
-            QString firstLine;
             QString errorMsg;
 
             if (exited)
@@ -671,70 +694,65 @@ DatabaseServerError DatabaseServer::initMysqlDatabase() const
             return DatabaseServerError(DatabaseServerError::StartError, errorMsg);
         }
 
-        QSqlQuery query(db);
-
-        if (!query.exec(QString::fromLatin1("USE %1;").arg(d->internalDBName)))
+        if (useDatabase)
         {
-            qCDebug(DIGIKAM_DATABASESERVER_LOG) << "Failed to use database"
-                                                << d->internalDBName;
-            qCDebug(DIGIKAM_DATABASESERVER_LOG) << "Query error:"
-                                                << query.lastError().text();
-            qCDebug(DIGIKAM_DATABASESERVER_LOG) << "Database error:"
-                                                << db.lastError().text();
-            qCDebug(DIGIKAM_DATABASESERVER_LOG) << "Trying to create database now";
+            QSqlQuery query(db);
 
-            if (query.exec(QString::fromLatin1("CREATE DATABASE %1;").arg(d->internalDBName)))
+            if (!query.exec(QString::fromLatin1("USE %1;").arg(d->internalDBName)))
             {
-                qCDebug(DIGIKAM_DATABASESERVER_LOG) << "Database was successfully created";
-            }
-            else
-            {
-                qCDebug(DIGIKAM_DATABASESERVER_LOG) << "Failed to create database";
+                qCDebug(DIGIKAM_DATABASESERVER_LOG) << "Failed to use database"
+                                                    << d->internalDBName;
                 qCDebug(DIGIKAM_DATABASESERVER_LOG) << "Query error:"
                                                     << query.lastError().text();
                 qCDebug(DIGIKAM_DATABASESERVER_LOG) << "Database error:"
                                                     << db.lastError().text();
+                qCDebug(DIGIKAM_DATABASESERVER_LOG) << "Trying to create database now";
 
-                QString  errorMsg = i18n("Failed to create database"
-                                         "<p>Query error: %1</p>"
-                                         "<p>Database error: %2</p>",
-                                         query.lastError().text(),
-                                         db.lastError().text());
+                if (query.exec(QString::fromLatin1("CREATE DATABASE %1;").arg(d->internalDBName)))
+                {
+                    qCDebug(DIGIKAM_DATABASESERVER_LOG) << "Database was successfully created";
+                }
+                else
+                {
+                    qCDebug(DIGIKAM_DATABASESERVER_LOG) << "Failed to create database";
+                    qCDebug(DIGIKAM_DATABASESERVER_LOG) << "Query error:"
+                                                        << query.lastError().text();
+                    qCDebug(DIGIKAM_DATABASESERVER_LOG) << "Database error:"
+                                                        << db.lastError().text();
 
-                return DatabaseServerError(DatabaseServerError::StartError, errorMsg);
+                    QString  errorMsg = i18n("Failed to create database"
+                                             "<p>Query error: %1</p>"
+                                             "<p>Database error: %2</p>",
+                                             query.lastError().text(),
+                                             db.lastError().text());
+
+                    error = DatabaseServerError(DatabaseServerError::StartError, errorMsg);
+                }
             }
-
-            // Make sure query is destroyed before we close the db
-
-            db.close();
         }
+
+        // Make sure query is destroyed before we close the db
+
+        db.close();
     }
 
     QSqlDatabase::removeDatabase(initCon);
 
-    return result;
+    return error;
 }
 
 DatabaseServerError DatabaseServer::upgradeMysqlDatabase()
 {
-    QApplication::restoreOverrideCursor();
+    QPointer<QProgressDialog> dialog = new QProgressDialog;
+    dialog->setLabelText(i18n("A MySQL database upgrade is "
+                              "in progress, please wait..."));
+    dialog->setCancelButton(nullptr);
+    dialog->setMinimumDuration(5000);
+    dialog->setModal(true);
+    dialog->setMinimum(0);
+    dialog->setMaximum(0);
 
-    QPointer<QMessageBox> msgBox = new QMessageBox(QMessageBox::Information,
-             qApp->applicationName(),
-             i18n("The database is now upgraded to the current "
-                  "server version, this can take a while."),
-             QMessageBox::Ok | QMessageBox::Cancel,
-             qApp->activeWindow());
-
-    int msgResult = msgBox->exec();
-    delete msgBox;
-
-    QApplication::setOverrideCursor(Qt::WaitCursor);
-
-    if (msgResult == QMessageBox::Cancel)
-    {
-        return DatabaseServerError();
-    }
+    DatabaseServerError error;
 
     // Synthesize the mysql upgrade command line arguments
 
@@ -750,36 +768,32 @@ DatabaseServerError DatabaseServer::upgradeMysqlDatabase()
 
 #endif
 
-    // Start the upgrade ptogram
+    // Start the upgrade program
 
-    QUrl upgradeUrl = QUrl::fromLocalFile(d->mysqlAdminPath).adjusted(QUrl::RemoveFilename);
-    upgradeUrl.setPath(upgradeUrl.path() + QLatin1String("mysql_upgrade"));
-
-    QProcess* const upgradeProcess = new QProcess();
-    upgradeProcess->setProcessEnvironment(adjustedEnvironmentForAppImage());
-    upgradeProcess->start(upgradeUrl.toLocalFile(), upgradeCmdArgs);
+    QProcess upgradeProcess;
+    upgradeProcess.setProcessEnvironment(adjustedEnvironmentForAppImage());
+    upgradeProcess.start(d->mysqlUpgradePath, upgradeCmdArgs);
 
     qCDebug(DIGIKAM_DATABASESERVER_LOG) << "Upgrade database:"
-                                        << upgradeProcess->program()
-                                        << upgradeProcess->arguments();
+                                        << upgradeProcess.program()
+                                        << upgradeProcess.arguments();
 
-    if (!upgradeProcess->waitForFinished(-1) || (upgradeProcess->exitCode() != 0))
+    while (!upgradeProcess.waitForFinished(250))
     {
-        QString errorMsg = processErrorLog(upgradeProcess,
-                                           i18n("Could not upgrade database."));
-
-        delete upgradeProcess;
-
-        return DatabaseServerError(DatabaseServerError::StartError, errorMsg);
+        qApp->processEvents();
     }
 
-    delete upgradeProcess;
+    delete dialog;
 
-    // Restart the database server.
+    if (upgradeProcess.exitCode() != 0)
+    {
+        QString errorMsg = processErrorLog(&upgradeProcess,
+                                           i18n("Could not upgrade database."));
 
-    stopDatabaseProcess();
+        error = DatabaseServerError(DatabaseServerError::StartError, errorMsg);
+    }
 
-    return startMysqlServer();
+    return error;
 }
 
 QString DatabaseServer::getcurrentAccountUserName() const
@@ -821,3 +835,5 @@ QString DatabaseServer::processErrorLog(QProcess* const process, const QString&
 }
 
 } // namespace Digikam
+
+#include "moc_databaseserver.cpp"
