@@ -6,7 +6,7 @@
  * Date        : 2005-05-25
  * Description : Emboss threaded image filter.
  *
- * SPDX-FileCopyrightText: 2005-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2005-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2006-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * SPDX-FileCopyrightText: 2010      by Martin Klapetek <martin dot klapetek at gmail dot com>
  *
@@ -17,8 +17,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_EMBOSS_FILTER_H
-#define DIGIKAM_EMBOSS_FILTER_H
+#pragma once
 
 // Local includes
 
@@ -74,9 +73,7 @@ private:
 
 private:
 
-    int m_depth;
+    int m_depth = 30;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_EMBOSS_FILTER_H
