@@ -4,7 +4,7 @@
  * Description : a tool to fix automatically camera lens aberrations
  *
  * SPDX-FileCopyrightText: 2008      by Adrian Schroeter <adrian at suse dot de>
- * SPDX-FileCopyrightText: 2008-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2008-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -17,7 +17,7 @@
 #include <QByteArray>
 #include <QCheckBox>
 #include <QString>
-#include <QtConcurrent>    // krazy:exclude=includes
+#include <QtConcurrentRun>
 #include <QScopedPointer>
 
 // Local includes
@@ -27,15 +27,20 @@
 #include "dmetadata.h"
 #include "digikam_globals_p.h"      // For KF6::Ki18n deprecated
 
-// Disable deprecated API from Lensfun.
-#if defined(Q_CC_GNU)
-#   pragma GCC diagnostic push
-#   pragma GCC diagnostic ignored "-Wdeprecated-declarations"
-#endif
+// Disable deprecated API from older Lensfun.
+
+#if !LENSFUN_TEST_VERSION(0,3,99)
+
+#   if defined(Q_CC_GNU)
+#       pragma GCC diagnostic push
+#       pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+#   endif
+
+#   if defined(Q_CC_CLANG)
+#       pragma clang diagnostic push
+#       pragma clang diagnostic ignored "-Wdeprecated-declarations"
+#   endif
 
-#if defined(Q_CC_CLANG)
-#   pragma clang diagnostic push
-#   pragma clang diagnostic ignored "-Wdeprecated-declarations"
 #endif
 
 namespace Digikam
@@ -81,7 +86,17 @@ LensFunFilter::~LensFunFilter()
 
     if (d->modifier)
     {
+
+#if LENSFUN_TEST_VERSION(0,3,99)
+
+        delete d->modifier;
+
+#else
+
         d->modifier->Destroy();
+
+#endif
+
     }
 
     delete d->iface;
@@ -124,7 +139,7 @@ QString LensFunFilter::DisplayableName()
 
 void LensFunFilter::filterCCAMultithreaded(uint start, uint stop)
 {
-    QScopedArrayPointer<float> pos(new float[m_orgImage.width() * 2 * 3]);
+    QScopedArrayPointer<float> pos(new float[m_orgImage.width() * 2 * 3] { 0.0F });
 
     for (unsigned int y = start ; runningFlag() && (y < stop) ; ++y)
     {
@@ -169,7 +184,7 @@ void LensFunFilter::filterVIGMultithreaded(uint start, uint stop)
 
 void LensFunFilter::filterDSTMultithreaded(uint start, uint stop)
 {
-    QScopedArrayPointer<float> pos(new float[m_orgImage.width() * 2 * 3]);
+    QScopedArrayPointer<float> pos(new float[m_orgImage.width() * 2 * 3] { 0.0F });
 
     for (unsigned int y = start ; runningFlag() && (y < stop) ; ++y)
     {
@@ -202,6 +217,31 @@ void LensFunFilter::filterImage()
         return;
     }
 
+    // Init lensfun lib, we are working on the full image.
+
+    lfPixelFormat colorDepth = (m_orgImage.bytesDepth() == 4) ? LF_PF_U8 : LF_PF_U16;
+    double focalLength       = d->iface->settings().focalLength;
+    double cropFactor        = d->iface->settings().cropFactor;
+
+    if (d->iface->settings().cameraModel == QLatin1String("DSC-RX100M6"))
+    {
+        focalLength = focalLength * cropFactor;
+    }
+
+#if LENSFUN_TEST_VERSION(0,3,99)
+
+    d->modifier              = new lfModifier(
+                                              d->iface->usedLens(),
+                                              focalLength,
+                                              cropFactor,
+                                              m_orgImage.width(),
+                                              m_orgImage.height(),
+                                              colorDepth,
+                                              false                    // no inverse
+                                             );
+
+#else
+
     // Lensfun Modifier flags to process
 
     int modifyFlags = 0;
@@ -226,37 +266,64 @@ void LensFunFilter::filterImage()
         modifyFlags |= LF_MODIFY_VIGNETTING;
     }
 
-    // Init lensfun lib, we are working on the full image.
-
-    lfPixelFormat colorDepth = m_orgImage.bytesDepth() == 4 ? LF_PF_U8 : LF_PF_U16;
-    double focalLength       = d->iface->settings().focalLength;
-    double cropFactor        = d->iface->settings().cropFactor;
-
     d->modifier              = lfModifier::Create(d->iface->usedLens(),
                                                   cropFactor,
                                                   m_orgImage.width(),
                                                   m_orgImage.height());
 
-    focalLength              = cropFactor > 1.0 ? focalLength * cropFactor
-                                                : focalLength;
-
-    int modflags             = d->modifier->Initialize(d->iface->usedLens(),
+    int modflags             = d->modifier->Initialize(
+                                                       d->iface->usedLens(),
                                                        colorDepth,
                                                        focalLength,
                                                        d->iface->settings().aperture,
                                                        d->iface->settings().subjectDistance,
-                                                       1.0, /* no scaling */
+                                                       1.0,             /* no scaling */
                                                        LF_RECTILINEAR,
                                                        modifyFlags,
-                                                       0    /*no inverse*/
+                                                       0                /* no inverse */
                                                       );
 
+#endif
+
     if (!d->modifier)
     {
         qCDebug(DIGIKAM_DIMG_LOG) << "ERROR: cannot initialize LensFun Modifier.";
         return;
+
     }
 
+#if LENSFUN_TEST_VERSION(0,3,99)
+
+    // Lensfun Modifier flags to process
+
+    int modflags = 0;
+    modflags    |= d->modifier->EnableScaling(1.0);             // no scaling
+
+    if (d->iface->settings().filterDST)
+    {
+        modflags |= d->modifier->EnableDistortionCorrection();
+    }
+
+    if (d->iface->settings().filterGEO)
+    {
+        modflags |= d->modifier->EnableProjectionTransform(LF_RECTILINEAR);
+    }
+
+    if (d->iface->settings().filterCCA)
+    {
+        modflags |= d->modifier->EnableTCACorrection();
+    }
+
+    if (d->iface->settings().filterVIG)
+    {
+        modflags |= d->modifier->EnableVignettingCorrection(
+                                                            d->iface->settings().aperture,
+                                                            d->iface->settings().subjectDistance
+                                                           );
+    }
+
+#endif
+
     // Calc necessary steps for progress bar
 
     int steps = ((d->iface->settings().filterCCA)                                   ? 1 : 0) +
@@ -285,7 +352,7 @@ void LensFunFilter::filterImage()
 
         QList <QFuture<void> > tasks;
 
-        for (int j = 0 ; runningFlag() && (j < vals.count()-1) ; ++j)
+        for (int j = 0 ; runningFlag() && (j < (vals.count() - 1)) ; ++j)
         {
             tasks.append(QtConcurrent::run(
 
@@ -299,12 +366,12 @@ void LensFunFilter::filterImage()
 
 #endif
 
-                                           vals[j],
-                                           vals[j+1])
+                                           vals[j    ],
+                                           vals[j + 1])
             );
         }
 
-        Q_FOREACH (QFuture<void> t, tasks)
+        for (QFuture<void> t : std::as_const(tasks))
         {
             t.waitForFinished();
         }
@@ -320,7 +387,7 @@ void LensFunFilter::filterImage()
     {
         QList <QFuture<void> > tasks;
 
-        for (int j = 0 ; runningFlag() && (j < vals.count()-1) ; ++j)
+        for (int j = 0 ; runningFlag() && (j < (vals.count() - 1)) ; ++j)
         {
             tasks.append(QtConcurrent::run(
 
@@ -334,12 +401,12 @@ void LensFunFilter::filterImage()
 
 #endif
 
-                                           vals[j],
-                                           vals[j+1])
+                                           vals[j    ],
+                                           vals[j + 1])
             );
         }
 
-        Q_FOREACH (QFuture<void> t, tasks)
+        for (QFuture<void> t : std::as_const(tasks))
         {
             t.waitForFinished();
         }
@@ -356,6 +423,7 @@ void LensFunFilter::filterImage()
         d->loop = 0;
 
         // we need a deep copy first
+
         d->tempImage = DImg(m_destImage.width(),
                             m_destImage.height(),
                             m_destImage.sixteenBit(),
@@ -365,7 +433,7 @@ void LensFunFilter::filterImage()
 
         QList <QFuture<void> > tasks;
 
-        for (int j = 0 ; runningFlag() && (j < vals.count()-1) ; ++j)
+        for (int j = 0 ; runningFlag() && (j < (vals.count() - 1)) ; ++j)
         {
             tasks.append(QtConcurrent::run(
 
@@ -379,12 +447,12 @@ void LensFunFilter::filterImage()
 
 #endif
 
-                                           vals[j],
-                                           vals[j+1])
+                                           vals[j    ],
+                                           vals[j + 1])
             );
         }
 
-        Q_FOREACH (QFuture<void> t, tasks)
+        for (QFuture<void> t : std::as_const(tasks))
         {
             t.waitForFinished();
         }
@@ -479,13 +547,18 @@ void LensFunFilter::readParameters(const Digikam::FilterAction& action)
 
 } // namespace Digikam
 
-// Restore warnings
-#if defined(Q_CC_GNU)
-#   pragma GCC diagnostic pop
-#endif
+// Restore warnings with older Lensfun API
+
+#if !LENSFUN_TEST_VERSION(0,3,99)
+
+#   if defined(Q_CC_GNU)
+#       pragma GCC diagnostic pop
+#   endif
+
+#   if defined(Q_CC_CLANG)
+#       pragma clang diagnostic pop
+#   endif
 
-#if defined(Q_CC_CLANG)
-#   pragma clang diagnostic pop
 #endif
 
 #include "moc_lensfunfilter.cpp"
