@@ -6,7 +6,7 @@
  * Date        : 2008-09-25
  * Description : a tool to convert RAW file to DNG - Export to target DNG.
  *
- * SPDX-FileCopyrightText: 2008-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2008-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2010-2011 by Jens Mueller <tschenser at gmx dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -86,8 +86,10 @@ int DNGWriter::Private::exportTarget(DNGWriterHost& host,
             previewImage.Reset(render.Render());
         }
 
-        bool useCompressedPreview = ((negative->RawLossyCompressedImage() != NULL) ||
-                                     (previewIndex > 0));
+        bool useCompressedPreview = (
+                                     (negative->RawLossyCompressedImage() != nullptr) ||
+                                     (previewIndex > 0)
+                                    );
 
         AutoPtr<dng_preview> preview(useCompressedPreview ? (dng_preview*) new dng_jpeg_preview
                                                           : (dng_preview*) new dng_image_preview);
@@ -135,17 +137,9 @@ int DNGWriter::Private::exportTarget(DNGWriterHost& host,
 
     qCDebug(DIGIKAM_GENERAL_LOG) << "DNGWriter: Creating DNG file" << outputInfo.fileName();
 
-    dng_image_writer writer;
-
-#ifdef __MINGW32__ // krazy:exclude=cpp
-
-    dng_file_stream filestream(QFile::encodeName(dngFilePath).constData(), true);
-
-#else
-
     dng_file_stream filestream(dngFilePath.toUtf8().constData(), true);
 
-#endif
+    dng_image_writer writer;
 
     writer.WriteDNG(host,
                     filestream,
