@@ -7,14 +7,13 @@
  * Description : file action manager
  *
  * SPDX-FileCopyrightText: 2009-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * SPDX-FileCopyrightText: 2011-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2011-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_FILE_ACTION_MNGR_PRIVATE_H
-#define DIGIKAM_FILE_ACTION_MNGR_PRIVATE_H
+#pragma once
 
 // Qt includes
 
@@ -177,7 +176,7 @@ public:
 
     FileActionMngr*                       q             = nullptr;
 
-    DatabaseWorkerInterface*              dbWorker;
+    DatabaseWorkerInterface*              dbWorker      = nullptr;
     ParallelAdapter<FileWorkerInterface>* fileWorker;
 
     QTimer*                               sleepTimer    = nullptr;
@@ -187,5 +186,3 @@ public:
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_FILE_ACTION_MNGR_PRIVATE_H
