@@ -6,15 +6,14 @@
  * Date        : 2007-10-22
  * Description : a widget to filter album contents by geolocation
  *
- * SPDX-FileCopyrightText: 2007-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2007-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2011      by Michael G. Hansen <mike at mghansen dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_GEO_LOCATION_FILTER_H
-#define DIGIKAM_GEO_LOCATION_FILTER_H
+#pragma once
 
 // Qt includes
 
@@ -49,5 +48,3 @@ private Q_SLOTS:
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_GEO_LOCATION_FILTER_H
