@@ -6,7 +6,7 @@
  * Date        : 2011-02-16
  * Description : pick label filter
  *
- * SPDX-FileCopyrightText: 2011-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2011-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -47,10 +47,11 @@ void PickLabelFilter::reset()
 QList<TAlbum*> PickLabelFilter::getCheckedPickLabelTags()
 {
     QList<TAlbum*> list;
-    int tagId   = 0;
-    TAlbum* tag = nullptr;
+    int tagId         = 0;
+    TAlbum* tag       = nullptr;
+    const auto labels = pickLabels();
 
-    Q_FOREACH (const PickLabel& pl, pickLabels())
+    for (const PickLabel& pl : labels)
     {
         tagId = TagsCache::instance()->tagForPickLabel(pl);
         tag   = AlbumManager::instance()->findTAlbum(tagId);
