@@ -6,7 +6,7 @@
  * Date        : 2004-11-17
  * Description : item properties side bar using data from digiKam database.
  *
- * SPDX-FileCopyrightText: 2004-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2004-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2007-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * SPDX-FileCopyrightText: 2010-2011 by Martin Klapetek <martin dot klapetek at gmail dot com>
  * SPDX-FileCopyrightText:      2011 by Michael G. Hansen <mike at mghansen dot de>
@@ -19,11 +19,11 @@
 
 // Qt includes
 
-#include <QRect>
+#include <QDir>
 #include <QColor>
+#include <QLocale>
 #include <QSplitter>
 #include <QFileInfo>
-#include <QLocale>
 #include <QScopedPointer>
 
 // KDE includes
@@ -50,10 +50,10 @@
 #include "tagscache.h"
 #include "dtrash.h"
 
-#ifdef HAVE_MARBLE
+#ifdef HAVE_GEOLOCATION
 #   include "itempropertiesgpstab.h"
 #   include "gpsiteminfosorter.h"
-#endif // HAVE_MARBLE
+#endif // HAVE_GEOLOCATION
 
 namespace Digikam
 {
@@ -62,26 +62,18 @@ class Q_DECL_HIDDEN ItemPropertiesSideBarDB::Private
 {
 public:
 
-    explicit Private()
-      : dirtyDesceditTab    (false),
-        hasPrevious         (false),
-        hasNext             (false),
-        hasItemInfoOwnership(false),
-        desceditTab         (nullptr),
-        versionsHistoryTab  (nullptr)
-    {
-    }
+    Private() = default;
 
-    bool                       dirtyDesceditTab;
-    bool                       hasPrevious;
-    bool                       hasNext;
-    bool                       hasItemInfoOwnership;
+    bool                       dirtyDesceditTab     = false;
+    bool                       hasPrevious          = false;
+    bool                       hasNext              = false;
+    bool                       hasItemInfoOwnership = false;
 
     ItemInfoList               currentInfos;
     ItemInfoList               allInfos;
     DImageHistory              currentHistory;
-    ItemDescEditTab*           desceditTab;
-    ItemPropertiesVersionsTab* versionsHistoryTab;
+    ItemDescEditTab*           desceditTab          = nullptr;
+    ItemPropertiesVersionsTab* versionsHistoryTab   = nullptr;
 };
 
 ItemPropertiesSideBarDB::ItemPropertiesSideBarDB(QWidget* const parent, SidebarSplitter* const splitter,
@@ -95,8 +87,23 @@ ItemPropertiesSideBarDB::ItemPropertiesSideBarDB(QWidget* const parent, SidebarS
     appendTab(d->desceditTab,        QIcon::fromTheme(QLatin1String("edit-text-frame-update")), i18nc("@title: database properties", "Captions"));
     appendTab(d->versionsHistoryTab, QIcon::fromTheme(QLatin1String("view-catalog")),           i18nc("@title: database properties", "Versions"));
 
+    m_propertiesTab->widget(ItemPropertiesTab::digiKamProperties)->setButtonIcon(QIcon::fromTheme(QLatin1String("document-edit")));
+    m_propertiesTab->widget(ItemPropertiesTab::digiKamProperties)->setButtonVisible(true);
+
+    m_propertiesTab->widget(ItemPropertiesTab::TagsProperties)->setButtonIcon(QIcon::fromTheme(QLatin1String("document-edit")));
+    m_propertiesTab->widget(ItemPropertiesTab::TagsProperties)->setButtonVisible(true);
+
+    m_propertiesTab->widget(ItemPropertiesTab::LocationProperties)->setButtonIcon(QIcon::fromTheme(QLatin1String("document-edit")));
+    m_propertiesTab->widget(ItemPropertiesTab::LocationProperties)->setButtonVisible(true);
+
+    m_propertiesTab->widget(ItemPropertiesTab::RightProperties)->setButtonIcon(QIcon::fromTheme(QLatin1String("document-edit")));
+    m_propertiesTab->widget(ItemPropertiesTab::RightProperties)->setButtonVisible(true);
+
     // ----------------------------------------------------------
 
+    connect(m_propertiesTab, SIGNAL(signalItemButtonPressed(int)),
+            this, SLOT(slotPropertiesButtonPressed(int)));
+
     connect(this, SIGNAL(signalChangedTab(QWidget*)),
             this, SLOT(slotChangedTab(QWidget*)));
 
@@ -106,6 +113,9 @@ ItemPropertiesSideBarDB::ItemPropertiesSideBarDB(QWidget* const parent, SidebarS
     connect(d->desceditTab, SIGNAL(signalPrevItem()),
             this, SIGNAL(signalPrevItem()));
 
+    connect(d->desceditTab, SIGNAL(signalRightSideBarBusy(bool)),
+            this, SIGNAL(signalRightSideBarBusy(bool)));
+
     connect(CoreDbAccess::databaseWatch(), SIGNAL(imageChange(ImageChangeset)),
             this, SLOT(slotImageChangeDatabase(ImageChangeset)));
 
@@ -344,7 +354,7 @@ void ItemPropertiesSideBarDB::changedTab(QWidget* const tab)
         d->dirtyDesceditTab = true;
     }
 
-#ifdef HAVE_MARBLE
+#ifdef HAVE_GEOLOCATION
 
     else if ((tab == m_gpsTab) && !m_dirtyGpsTab)
     {
@@ -380,7 +390,7 @@ void ItemPropertiesSideBarDB::changedTab(QWidget* const tab)
         m_dirtyGpsTab = true;
     }
 
-#endif // HAVE_MARBLE
+#endif // HAVE_GEOLOCATION
 
     else if ((tab == d->versionsHistoryTab) && !m_dirtyHistoryTab)
     {
@@ -400,11 +410,11 @@ void ItemPropertiesSideBarDB::changedTab(QWidget* const tab)
         m_dirtyHistoryTab = true;
     }
 
-#ifdef HAVE_MARBLE
+#ifdef HAVE_GEOLOCATION
 
     m_gpsTab->setActive(tab == m_gpsTab);
 
-#endif // HAVE_MARBLE
+#endif // HAVE_GEOLOCATION
 
     unsetCursor();
 }
@@ -439,15 +449,15 @@ void ItemPropertiesSideBarDB::slotImageChangeDatabase(const ImageChangeset& chan
 
         if      ((tab == m_propertiesStackedView)
 
-#ifdef HAVE_MARBLE
+#ifdef HAVE_GEOLOCATION
 
             || (tab == m_gpsTab)
 
-#endif // HAVE_MARBLE
+#endif // HAVE_GEOLOCATION
 
            )
         {
-            ItemInfo& info = d->currentInfos.first();
+            const ItemInfo& info = d->currentInfos.first();
 
             if (changeset.ids().contains(info.id()))
             {
@@ -470,11 +480,11 @@ void ItemPropertiesSideBarDB::slotImageChangeDatabase(const ImageChangeset& chan
 
                 if ((tab == m_propertiesStackedView)
 
-#ifdef HAVE_MARBLE
+#ifdef HAVE_GEOLOCATION
 
                     || (tab == m_gpsTab)
 
-#endif // HAVE_MARBLE
+#endif // HAVE_GEOLOCATION
 
                    )
                 {
@@ -486,7 +496,7 @@ void ItemPropertiesSideBarDB::slotImageChangeDatabase(const ImageChangeset& chan
         }
         else if ((tab == d->desceditTab) && d->desceditTab->isModified())
         {
-            ItemInfo& info = d->currentInfos.first();
+            const ItemInfo& info = d->currentInfos.first();
 
             if (changeset.ids().contains(info.id()))
             {
@@ -498,6 +508,26 @@ void ItemPropertiesSideBarDB::slotImageChangeDatabase(const ImageChangeset& chan
                 }
             }
         }
+        else if (tab == m_metadataTab)
+        {
+            const ItemInfo& info = d->currentInfos.first();
+
+            if (changeset.ids().contains(info.id()))
+            {
+                // trigger an update, if changes touch creation date
+
+                DatabaseFields::Set set = changeset.changes();
+
+                if (set & DatabaseFields::CreationDate)
+                {
+                    // update now - reuse code form changedTab
+
+                    m_dirtyMetadataTab = false;
+
+                    changedTab(tab);
+                }
+            }
+        }
     }
 }
 
@@ -514,7 +544,7 @@ void ItemPropertiesSideBarDB::slotImageTagChanged(const ImageTagChangeset& chang
 
         if      (tab == m_propertiesStackedView)
         {
-            ItemInfo& info = d->currentInfos.first();
+            const ItemInfo& info = d->currentInfos.first();
 
             if (changeset.ids().contains(info.id()))
             {
@@ -524,14 +554,15 @@ void ItemPropertiesSideBarDB::slotImageTagChanged(const ImageTagChangeset& chang
         }
         else if ((tab == d->desceditTab) && d->desceditTab->isModified())
         {
-            ItemInfo& info = d->currentInfos.first();
+            const ItemInfo& info = d->currentInfos.first();
 
             if (changeset.ids().contains(info.id()))
             {
                 QVector<int> colorLabelTags = TagsCache::instance()->colorLabelTags();
                 QVector<int> pickLabelTags  = TagsCache::instance()->pickLabelTags();
+                const auto ctags            = changeset.tags();
 
-                Q_FOREACH (int ctag, changeset.tags())
+                for (int ctag : ctags)
                 {
                     if (colorLabelTags.contains(ctag))
                     {
@@ -540,7 +571,9 @@ void ItemPropertiesSideBarDB::slotImageTagChanged(const ImageTagChangeset& chang
                     }
                 }
 
-                Q_FOREACH (int ptag, changeset.tags())
+                const auto ptags            = changeset.tags();
+
+                for (int ptag : ptags)
                 {
                     if (pickLabelTags.contains(ptag))
                     {
@@ -598,7 +631,7 @@ void ItemPropertiesSideBarDB::refreshTagsView()
 
 void ItemPropertiesSideBarDB::setImagePropertiesInformation(const QUrl& url)
 {
-    Q_FOREACH (const ItemInfo& info, d->currentInfos)
+    for (const ItemInfo& info : std::as_const(d->currentInfos))
     {
         if (info.fileUrl() == url)
         {   // cppcheck-suppress useStlAlgorithm
@@ -615,10 +648,19 @@ void ItemPropertiesSideBarDB::setImagePropertiesInformation(const QUrl& url)
             str = QLocale().toString(commonInfo.fileModificationDate, QLocale::ShortFormat);
             m_propertiesTab->setFileModifiedDate(str);
 
-            str = QString::fromUtf8("%1 (%2)").arg(ItemPropertiesTab::humanReadableBytesCount(fileInfo.size()))
+            str = QString::fromUtf8("%1 (%2)").arg(ItemPropertiesTab::humanReadableBytesCount(commonInfo.fileSize))
                                     .arg(QLocale().toString(commonInfo.fileSize));
             m_propertiesTab->setFileSize(str);
 
+            // If the collection is offline, url is empty.
+
+            if (url.isEmpty())
+            {
+                m_propertiesTab->setFileName(info.name());
+                QString path(QLatin1String("???") + info.relativePath());
+                m_propertiesTab->setFileFolder(QDir::toNativeSeparators(path));
+            }
+
             //  These infos are not stored in DB
 
             m_propertiesTab->setFileOwner(QString::fromUtf8("%1 - %2").arg(fileInfo.owner()).arg(fileInfo.group()));
@@ -653,6 +695,8 @@ void ItemPropertiesSideBarDB::setImagePropertiesInformation(const QUrl& url)
             m_propertiesTab->setImageBitDepth(i18nc("@info: item properties", "%1 bpp", commonInfo.colorDepth));
             m_propertiesTab->setHasSidecar(DMetadata::hasSidecar(url.toLocalFile()) ? i18nc("@info: item properties", "Yes")
                                                                                     : i18nc("@info: item properties", "No"));
+            m_propertiesTab->setHasGPSInfo(info.hasCoordinates() ? i18nc("@info: item properties", "Yes")
+                                                                 : i18nc("@info: item properties", "No"));
             m_propertiesTab->setImageColorMode(commonInfo.colorModel.isEmpty() ? unavailable : commonInfo.colorModel);
 
             // -- Photograph information ------------------------------------------
@@ -724,14 +768,42 @@ void ItemPropertiesSideBarDB::setImagePropertiesInformation(const QUrl& url)
 
             // -- Caption / Tags ------------------------------------------
 
+            m_propertiesTab->setTitle(info.title());
             m_propertiesTab->setCaption(info.comment());
             m_propertiesTab->setPickLabel(info.pickLabel());
             m_propertiesTab->setColorLabel(info.colorLabel());
             m_propertiesTab->setRating(info.rating());
-            QList<int> tagIds = info.tagIds();
-            m_propertiesTab->setTags(TagsCache::instance()->tagPaths(tagIds, TagsCache::NoLeadingSlash, TagsCache::NoHiddenTags),
-                                     TagsCache::instance()->tagNames(tagIds, TagsCache::NoHiddenTags));
-            m_propertiesTab->showOrHideCaptionAndTags();
+            QList<int> allTagIds = info.tagIds();
+            QList<int> regularTagIds;
+            QList<int> peopleTagIds;
+
+            for (int t : std::as_const(allTagIds))
+            {
+                if (TagsCache::instance()->properties(t).contains(QLatin1String("person")))
+                {
+                    peopleTagIds << t;
+                }
+                else
+                {
+                    regularTagIds << t;
+                }
+            }
+
+            m_propertiesTab->setTags(
+                                     TagsCache::instance()->tagPaths(regularTagIds, TagsCache::NoLeadingSlash, TagsCache::NoHiddenTags),
+                                     TagsCache::instance()->tagNames(regularTagIds, TagsCache::NoHiddenTags),
+                                     TagsCache::instance()->tagPaths(peopleTagIds, TagsCache::NoLeadingSlash, TagsCache::NoHiddenTags),
+                                     TagsCache::instance()->tagNames(peopleTagIds, TagsCache::NoHiddenTags)
+                                    );
+
+            m_propertiesTab->setTemplate(info.metadataTemplate());
+
+            m_propertiesTab->setVersionnedInfo((info.hasDerivedImages() || info.hasAncestorImages()) ? i18nc("@info: item properties", "Yes")
+                                                                                                     : i18nc("@info: item properties", "No"));
+            m_propertiesTab->setGroupedInfo((info.isGrouped() || info.hasGroupedImages()) ? i18nc("@info: item properties", "Yes")
+                                                                                          : i18nc("@info: item properties", "No"));
+
+            m_propertiesTab->showOrHideCachedProperties();
 
             return;
         }
@@ -746,7 +818,7 @@ void ItemPropertiesSideBarDB::setImageSelectionPropertiesInformation()
 
     qint64 selectionFileSize = 0;
 
-    Q_FOREACH (const ItemInfo& info, d->currentInfos)
+    for (const ItemInfo& info : std::as_const(d->currentInfos))
     {
         // cppcheck-suppress useStlAlgorithm
         selectionFileSize += info.fileSize();
@@ -760,7 +832,7 @@ void ItemPropertiesSideBarDB::setImageSelectionPropertiesInformation()
 
     qint64 totalFileSize = 0;
 
-    Q_FOREACH (const ItemInfo& info, d->allInfos)
+    for (const ItemInfo& info : std::as_const(d->allInfos))
     {
         // cppcheck-suppress useStlAlgorithm
         totalFileSize += info.fileSize();
@@ -811,7 +883,7 @@ void ItemPropertiesSideBarDB::slotPopupTagsView()
     d->desceditTab->setFocusToTagsView();
 }
 
-#ifdef HAVE_MARBLE
+#ifdef HAVE_GEOLOCATION
 
 bool ItemPropertiesSideBarDB::GPSItemInfofromItemInfo(const ItemInfo& imageInfo, GPSItemInfo* const gpsItemInfo)
 {
@@ -837,6 +909,41 @@ bool ItemPropertiesSideBarDB::GPSItemInfofromItemInfo(const ItemInfo& imageInfo,
     return true;
 }
 
-#endif // HAVE_MARBLE
+#endif // HAVE_GEOLOCATION
+
+void ItemPropertiesSideBarDB::slotPropertiesButtonPressed(int index)
+{
+    switch (index)
+    {
+        case ItemPropertiesTab::digiKamProperties:
+        {
+            setActiveTab(d->desceditTab);
+            d->desceditTab->setCurrentTab(ItemDescEditTab::DESCRIPTIONS);
+            break;
+        }
+
+        case ItemPropertiesTab::TagsProperties:
+        {
+            setActiveTab(d->desceditTab);
+            d->desceditTab->setCurrentTab(ItemDescEditTab::TAGS);
+            break;
+        }
+
+        case ItemPropertiesTab::LocationProperties:
+        case ItemPropertiesTab::RightProperties:
+        {
+            setActiveTab(d->desceditTab);
+            d->desceditTab->setCurrentTab(ItemDescEditTab::INFOS);
+            break;
+        }
+
+        default:
+        {
+            break;
+        }
+    }
+}
 
 } // namespace Digikam
+
+#include "moc_itempropertiessidebardb.cpp"
