@@ -4,9 +4,9 @@
  * https://www.digikam.org
  *
  * date        : 2006-09-13
- * Description : Raw Decoder settings widgets
+ * Description : Raw Decoder settings widget
  *
- * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2006-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  * SPDX-FileCopyrightText: 2007-2008 by Guillaume Castagnino <casta at xwing dot info>
  *
@@ -14,37 +14,6 @@
  *
  * ============================================================ */
 
-#define OPTIONFIXCOLORSHIGHLIGHTSENTRY                 "FixColorsHighlights"
-#define OPTIONDECODESIXTEENBITENTRY                    "SixteenBitsImage"
-#define OPTIONWHITEBALANCEENTRY                        "White Balance"
-#define OPTIONCUSTOMWHITEBALANCEENTRY                  "Custom White Balance"
-#define OPTIONCUSTOMWBGREENENTRY                       "Custom White Balance Green"
-#define OPTIONFOURCOLORRGBENTRY                        "Four Color RGB"
-#define OPTIONUNCLIPCOLORSENTRY                        "Unclip Color"
-#define OPTIONDONTSTRETCHPIXELSSENTRY                  "Dont Stretch Pixels"        // krazy:exclude=spelling
-#define OPTIONMEDIANFILTERPASSESENTRY                  "Median Filter Passes"       // krazy:exclude=spelling
-#define OPTIONNOISEREDUCTIONTYPEENTRY                  "Noise Reduction Type"
-#define OPTIONNOISEREDUCTIONTHRESHOLDENTRY             "Noise Reduction Threshold"
-#define OPTIONAUTOBRIGHTNESSENTRY                      "AutoBrightness"
-#define OPTIONDECODINGQUALITYENTRY                     "Decoding Quality"
-#define OPTIONINPUTCOLORSPACEENTRY                     "Input Color Space"
-#define OPTIONOUTPUTCOLORSPACEENTRY                    "Output Color Space"
-#define OPTIONINPUTCOLORPROFILEENTRY                   "Input Color Profile"
-#define OPTIONOUTPUTCOLORPROFILEENTRY                  "Output Color Profile"
-#define OPTIONBRIGHTNESSMULTIPLIERENTRY                "Brightness Multiplier"
-#define OPTIONUSEBLACKPOINTENTRY                       "Use Black Point"
-#define OPTIONBLACKPOINTENTRY                          "Black Point"
-#define OPTIONUSEWHITEPOINTENTRY                       "Use White Point"
-#define OPTIONWHITEPOINTENTRY                          "White Point"
-
-//-- Extended demosaicing settings ----------------------------------------------------------
-
-#define OPTIONDCBITERATIONSENTRY                       "Dcb Iterations"
-#define OPTIONDCBENHANCEFLENTRY                        "Dcb Enhance Filter"
-#define OPTIONEXPOCORRECTIONENTRY                      "Expo Correction"
-#define OPTIONEXPOCORRECTIONSHIFTENTRY                 "Expo Correction Shift"
-#define OPTIONEXPOCORRECTIONHIGHLIGHTENTRY             "Expo Correction Highlight"
-
 #include "drawdecoderwidget.h"
 
 // C++ includes
@@ -68,6 +37,7 @@
 
 // Local includes
 
+#include "digikam_globals.h"
 #include "drawdecoder.h"
 #include "dnuminput.h"
 #include "dcombobox.h"
@@ -80,126 +50,112 @@ class Q_DECL_HIDDEN DRawDecoderWidget::Private
 {
 public:
 
-    explicit Private()
-      : demosaicingSettings             (nullptr),
-        whiteBalanceSettings            (nullptr),
-        correctionsSettings             (nullptr),
-        colormanSettings                (nullptr),
-        whiteBalanceLabel               (nullptr),
-        customWhiteBalanceLabel         (nullptr),
-        customWhiteBalanceGreenLabel    (nullptr),
-        brightnessLabel                 (nullptr),
-        RAWQualityLabel                 (nullptr),
-        NRLabel1                        (nullptr),
-        unclipColorLabel                (nullptr),
-        reconstructLabel                (nullptr),
-        inputColorSpaceLabel            (nullptr),
-        outputColorSpaceLabel           (nullptr),
-        medianFilterPassesLabel         (nullptr),
-        noiseReductionLabel             (nullptr),
-        expoCorrectionShiftLabel        (nullptr),
-        expoCorrectionHighlightLabel    (nullptr),
-        blackPointCheckBox              (nullptr),
-        whitePointCheckBox              (nullptr),
-        sixteenBitsImage                (nullptr),
-        autoBrightnessBox               (nullptr),
-        fourColorCheckBox               (nullptr),
-        dontStretchPixelsCheckBox       (nullptr),
-        fixColorsHighlightsBox          (nullptr),
-        refineInterpolationBox          (nullptr),
-        expoCorrectionBox               (nullptr),
-        inIccUrlEdit                    (nullptr),
-        outIccUrlEdit                   (nullptr),
-        noiseReductionComboBox          (nullptr),
-        whiteBalanceComboBox            (nullptr),
-        RAWQualityComboBox              (nullptr),
-        unclipColorComboBox             (nullptr),
-        inputColorSpaceComboBox         (nullptr),
-        outputColorSpaceComboBox        (nullptr),
-        customWhiteBalanceSpinBox       (nullptr),
-        reconstructSpinBox              (nullptr),
-        blackPointSpinBox               (nullptr),
-        whitePointSpinBox               (nullptr),
-        NRSpinBox1                      (nullptr),
-        medianFilterPassesSpinBox       (nullptr),
-        customWhiteBalanceGreenSpinBox  (nullptr),
-        brightnessSpinBox               (nullptr),
-        expoCorrectionShiftSpinBox      (nullptr),
-        expoCorrectionHighlightSpinBox  (nullptr)
-    {
-    }
+    Private() = default;
 
-    /** Convert Exposure correction shift E.V value from GUI to Linear value needs by libraw decoder.
+    /**
+     * Convert Exposure correction shift E.V value from GUI to Linear value needs by libraw decoder.
      */
     double shiftExpoFromEvToLinear(double ev) const
     {
         // From GUI : -2.0EV => 0.25
         //            +3.0EV => 8.00
-        return (1.55*ev + 3.35);
+        return (1.55 * ev + 3.35);
     }
 
-    /** Convert Exposure correction shift Linear value from liraw decoder to E.V value needs by GUI.
+    /**
+     * Convert Exposure correction shift Linear value from liraw decoder to E.V value needs by GUI.
      */
     double shiftExpoFromLinearToEv(double lin) const
     {
         // From GUI : 0.25 => -2.0EV
         //            8.00 => +3.0EV
-        return ((lin-3.35) / 1.55);
+        return ((lin - 3.35) / 1.55);
     }
 
 public:
 
-    QWidget*         demosaicingSettings;
-    QWidget*         whiteBalanceSettings;
-    QWidget*         correctionsSettings;
-    QWidget*         colormanSettings;
+    QWidget*         demosaicingSettings                = nullptr;
+    QWidget*         whiteBalanceSettings               = nullptr;
+    QWidget*         correctionsSettings                = nullptr;
+    QWidget*         colormanSettings                   = nullptr;
 
-    QLabel*          whiteBalanceLabel;
-    QLabel*          customWhiteBalanceLabel;
-    QLabel*          customWhiteBalanceGreenLabel;
-    QLabel*          brightnessLabel;
-    QLabel*          RAWQualityLabel;
-    QLabel*          NRLabel1;
-    QLabel*          unclipColorLabel;
-    QLabel*          reconstructLabel;
-    QLabel*          inputColorSpaceLabel;
-    QLabel*          outputColorSpaceLabel;
-    QLabel*          medianFilterPassesLabel;
-    QLabel*          noiseReductionLabel;
-    QLabel*          expoCorrectionShiftLabel;
-    QLabel*          expoCorrectionHighlightLabel;
+    QLabel*          whiteBalanceLabel                  = nullptr;
+    QLabel*          customWhiteBalanceLabel            = nullptr;
+    QLabel*          customWhiteBalanceGreenLabel       = nullptr;
+    QLabel*          brightnessLabel                    = nullptr;
+    QLabel*          RAWQualityLabel                    = nullptr;
+    QLabel*          NRLabel1                           = nullptr;
+    QLabel*          unclipColorLabel                   = nullptr;
+    QLabel*          reconstructLabel                   = nullptr;
+    QLabel*          inputColorSpaceLabel               = nullptr;
+    QLabel*          outputColorSpaceLabel              = nullptr;
+    QLabel*          medianFilterPassesLabel            = nullptr;
+    QLabel*          noiseReductionLabel                = nullptr;
+    QLabel*          expoCorrectionShiftLabel           = nullptr;
+    QLabel*          expoCorrectionHighlightLabel       = nullptr;
 
-    QCheckBox*       blackPointCheckBox;
-    QCheckBox*       whitePointCheckBox;
-    QCheckBox*       sixteenBitsImage;
-    QCheckBox*       autoBrightnessBox;
-    QCheckBox*       fourColorCheckBox;
-    QCheckBox*       dontStretchPixelsCheckBox;
-    QCheckBox*       fixColorsHighlightsBox;
-    QCheckBox*       refineInterpolationBox;
-    QCheckBox*       expoCorrectionBox;
+    QCheckBox*       blackPointCheckBox                 = nullptr;
+    QCheckBox*       whitePointCheckBox                 = nullptr;
+    QCheckBox*       sixteenBitsImage                   = nullptr;
+    QCheckBox*       autoBrightnessBox                  = nullptr;
+    QCheckBox*       fourColorCheckBox                  = nullptr;
+    QCheckBox*       dontStretchPixelsCheckBox          = nullptr;
+    QCheckBox*       fixColorsHighlightsBox             = nullptr;
+    QCheckBox*       refineInterpolationBox             = nullptr;
+    QCheckBox*       expoCorrectionBox                  = nullptr;
 
-    DFileSelector*   inIccUrlEdit;
-    DFileSelector*   outIccUrlEdit;
+    DFileSelector*   inIccUrlEdit                       = nullptr;
+    DFileSelector*   outIccUrlEdit                      = nullptr;
 
-    DComboBox*       noiseReductionComboBox;
-    DComboBox*       whiteBalanceComboBox;
-    DComboBox*       RAWQualityComboBox;
-    DComboBox*       unclipColorComboBox;
-    DComboBox*       inputColorSpaceComboBox;
-    DComboBox*       outputColorSpaceComboBox;
+    DComboBox*       noiseReductionComboBox             = nullptr;
+    DComboBox*       whiteBalanceComboBox               = nullptr;
+    DComboBox*       RAWQualityComboBox                 = nullptr;
+    DComboBox*       unclipColorComboBox                = nullptr;
+    DComboBox*       inputColorSpaceComboBox            = nullptr;
+    DComboBox*       outputColorSpaceComboBox           = nullptr;
 
-    DIntNumInput*    customWhiteBalanceSpinBox;
-    DIntNumInput*    reconstructSpinBox;
-    DIntNumInput*    blackPointSpinBox;
-    DIntNumInput*    whitePointSpinBox;
-    DIntNumInput*    NRSpinBox1;
-    DIntNumInput*    medianFilterPassesSpinBox;
+    DIntNumInput*    customWhiteBalanceSpinBox          = nullptr;
+    DIntNumInput*    reconstructSpinBox                 = nullptr;
+    DIntNumInput*    blackPointSpinBox                  = nullptr;
+    DIntNumInput*    whitePointSpinBox                  = nullptr;
+    DIntNumInput*    NRSpinBox1                         = nullptr;
+    DIntNumInput*    medianFilterPassesSpinBox          = nullptr;
 
-    DDoubleNumInput* customWhiteBalanceGreenSpinBox;
-    DDoubleNumInput* brightnessSpinBox;
-    DDoubleNumInput* expoCorrectionShiftSpinBox;
-    DDoubleNumInput* expoCorrectionHighlightSpinBox;
+    DDoubleNumInput* customWhiteBalanceGreenSpinBox     = nullptr;
+    DDoubleNumInput* brightnessSpinBox                  = nullptr;
+    DDoubleNumInput* expoCorrectionShiftSpinBox         = nullptr;
+    DDoubleNumInput* expoCorrectionHighlightSpinBox     = nullptr;
+
+    const QString OPTIONFIXCOLORSHIGHLIGHTSENTRY        = QLatin1String("FixColorsHighlights");
+    const QString OPTIONDECODESIXTEENBITENTRY           = QLatin1String("SixteenBitsImage");
+    const QString OPTIONWHITEBALANCEENTRY               = QLatin1String("White Balance");
+    const QString OPTIONCUSTOMWHITEBALANCEENTRY         = QLatin1String("Custom White Balance");
+    const QString OPTIONCUSTOMWBGREENENTRY              = QLatin1String("Custom White Balance Green");
+    const QString OPTIONFOURCOLORRGBENTRY               = QLatin1String("Four Color RGB");
+    const QString OPTIONUNCLIPCOLORSENTRY               = QLatin1String("Unclip Color");
+    const QString OPTIONDONTSTRETCHPIXELSSENTRY         = QLatin1String("Dont Stretch Pixels");        // krazy:exclude=spelling
+    const QString OPTIONMEDIANFILTERPASSESENTRY         = QLatin1String("Median Filter Passes");       // krazy:exclude=spelling
+    const QString OPTIONNOISEREDUCTIONTYPEENTRY         = QLatin1String("Noise Reduction Type");
+    const QString OPTIONNOISEREDUCTIONTHRESHOLDENTRY    = QLatin1String("Noise Reduction Threshold");
+    const QString OPTIONAUTOBRIGHTNESSENTRY             = QLatin1String("AutoBrightness");
+    const QString OPTIONDECODINGQUALITYENTRY            = QLatin1String("Decoding Quality");
+    const QString OPTIONINPUTCOLORSPACEENTRY            = QLatin1String("Input Color Space");
+    const QString OPTIONOUTPUTCOLORSPACEENTRY           = QLatin1String("Output Color Space");
+    const QString OPTIONINPUTCOLORPROFILEENTRY          = QLatin1String("Input Color Profile");
+    const QString OPTIONOUTPUTCOLORPROFILEENTRY         = QLatin1String("Output Color Profile");
+    const QString OPTIONBRIGHTNESSMULTIPLIERENTRY       = QLatin1String("Brightness Multiplier");
+    const QString OPTIONUSEBLACKPOINTENTRY              = QLatin1String("Use Black Point");
+    const QString OPTIONBLACKPOINTENTRY                 = QLatin1String("Black Point");
+    const QString OPTIONUSEWHITEPOINTENTRY              = QLatin1String("Use White Point");
+    const QString OPTIONWHITEPOINTENTRY                 = QLatin1String("White Point");
+
+    // -- Extended demosaicing settings ----------------------------------------------------------
+
+    const QString OPTIONDCBITERATIONSENTRY              = QLatin1String("Dcb Iterations");
+    const QString OPTIONDCBENHANCEFLENTRY               = QLatin1String("Dcb Enhance Filter");
+    const QString OPTIONEXPOCORRECTIONENTRY             = QLatin1String("Expo Correction");
+    const QString OPTIONEXPOCORRECTIONSHIFTENTRY        = QLatin1String("Expo Correction Shift");
+    const QString OPTIONEXPOCORRECTIONHIGHLIGHTENTRY    = QLatin1String("Expo Correction Highlight");
 };
 
 DRawDecoderWidget::DRawDecoderWidget(QWidget* const parent, int advSettings)
@@ -279,6 +235,7 @@ void DRawDecoderWidget::setup(int advSettings)
     d->RAWQualityComboBox = new DComboBox(d->demosaicingSettings);
 
     // Original Raw engine demosaicing methods
+
     d->RAWQualityComboBox->insertItem(0, i18nc("@item:inlistbox Quality", "Bilinear"), QVariant(DRawDecoderSettings::BILINEAR));
     d->RAWQualityComboBox->insertItem(1, i18nc("@item:inlistbox Quality", "VNG"),      QVariant(DRawDecoderSettings::VNG));
     d->RAWQualityComboBox->insertItem(2, i18nc("@item:inlistbox Quality", "PPG"),      QVariant(DRawDecoderSettings::PPG));
@@ -507,8 +464,8 @@ void DRawDecoderWidget::setup(int advSettings)
         d->whitePointSpinBox->hide();
     }
 
-    const int spacing = qMin(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing),
-                             QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
+    const int spacing = layoutSpacing();
+
 
     whiteBalanceLayout->addWidget(d->whiteBalanceLabel,              0,  0, 1, 1);
     whiteBalanceLayout->addWidget(d->whiteBalanceComboBox,           0,  1, 1, 2);
@@ -687,7 +644,7 @@ void DRawDecoderWidget::setup(int advSettings)
     connect(d->expoCorrectionShiftSpinBox, &DDoubleNumInput::valueChanged,
             this, &DRawDecoderWidget::slotExpoCorrectionShiftChanged);
 
-    // Wrapper to Q_EMIT signal when something is changed in settings.
+    // Wrapper to emit signal when something is changed in settings.
 
     connect(d->inIccUrlEdit->lineEdit(), &QLineEdit::textChanged,
             this, &DRawDecoderWidget::signalSettingsChanged);
@@ -800,6 +757,7 @@ void DRawDecoderWidget::resetToDefault()
 void DRawDecoderWidget::slotsixteenBitsImageToggled(bool b)
 {
     setEnabledBrightnessSettings(!b);
+
     Q_EMIT signalSixteenBitsImageToggled(d->sixteenBitsImage->isChecked());
 }
 
@@ -849,6 +807,7 @@ void DRawDecoderWidget::slotNoiseReductionChanged(int item)
         case DRawDecoderSettings::FBDDNR:
         {
             // NOTE : no ops
+
             break;
         }
 
@@ -1190,68 +1149,71 @@ void DRawDecoderWidget::writeSettings(KConfigGroup& group)
     DExpanderBox::writeSettings(group);
 }
 
-void DRawDecoderWidget::readSettings(DRawDecoderSettings& prm, KConfigGroup& group)
+void DRawDecoderWidget::readSettings(DRawDecoderSettings& prm, const KConfigGroup& group)
 {
+    Private d;
     DRawDecoderSettings defaultPrm;
 
-    prm.fixColorsHighlights     = group.readEntry(OPTIONFIXCOLORSHIGHLIGHTSENTRY,                                     defaultPrm.fixColorsHighlights);
-    prm.sixteenBitsImage        = group.readEntry(OPTIONDECODESIXTEENBITENTRY,                                        defaultPrm.sixteenBitsImage);
-    prm.whiteBalance            = (DRawDecoderSettings::WhiteBalance)group.readEntry(OPTIONWHITEBALANCEENTRY,         (int)defaultPrm.whiteBalance);
-    prm.customWhiteBalance      = group.readEntry(OPTIONCUSTOMWHITEBALANCEENTRY,                                      defaultPrm.customWhiteBalance);
-    prm.customWhiteBalanceGreen = group.readEntry(OPTIONCUSTOMWBGREENENTRY,                                           defaultPrm.customWhiteBalanceGreen);
-    prm.RGBInterpolate4Colors   = group.readEntry(OPTIONFOURCOLORRGBENTRY,                                            defaultPrm.RGBInterpolate4Colors);
-    prm.unclipColors            = group.readEntry(OPTIONUNCLIPCOLORSENTRY,                                            defaultPrm.unclipColors);
-    prm.DontStretchPixels       = group.readEntry(OPTIONDONTSTRETCHPIXELSSENTRY,                                       defaultPrm.DontStretchPixels);
-    prm.NRType                  = (DRawDecoderSettings::NoiseReduction)group.readEntry(OPTIONNOISEREDUCTIONTYPEENTRY, (int)defaultPrm.NRType);
-    prm.brightness              = group.readEntry(OPTIONBRIGHTNESSMULTIPLIERENTRY,                                    defaultPrm.brightness);
-    prm.enableBlackPoint        = group.readEntry(OPTIONUSEBLACKPOINTENTRY,                                           defaultPrm.enableBlackPoint);
-    prm.blackPoint              = group.readEntry(OPTIONBLACKPOINTENTRY,                                              defaultPrm.blackPoint);
-    prm.enableWhitePoint        = group.readEntry(OPTIONUSEWHITEPOINTENTRY,                                           defaultPrm.enableWhitePoint);
-    prm.whitePoint              = group.readEntry(OPTIONWHITEPOINTENTRY,                                              defaultPrm.whitePoint);
-    prm.medianFilterPasses      = group.readEntry(OPTIONMEDIANFILTERPASSESENTRY,                                      defaultPrm.medianFilterPasses);
-    prm.NRThreshold             = group.readEntry(OPTIONNOISEREDUCTIONTHRESHOLDENTRY,                                 defaultPrm.NRThreshold);
-    prm.RAWQuality              = (DRawDecoderSettings::DecodingQuality)group.readEntry(OPTIONDECODINGQUALITYENTRY,   (int)defaultPrm.RAWQuality);
-    prm.outputColorSpace        = (DRawDecoderSettings::OutputColorSpace)group.readEntry(OPTIONOUTPUTCOLORSPACEENTRY, (int)defaultPrm.outputColorSpace);
-    prm.autoBrightness          = group.readEntry(OPTIONAUTOBRIGHTNESSENTRY,                                          defaultPrm.autoBrightness);
+    prm.fixColorsHighlights     = group.readEntry(d.OPTIONFIXCOLORSHIGHLIGHTSENTRY,                                     defaultPrm.fixColorsHighlights);
+    prm.sixteenBitsImage        = group.readEntry(d.OPTIONDECODESIXTEENBITENTRY,                                        defaultPrm.sixteenBitsImage);
+    prm.whiteBalance            = (DRawDecoderSettings::WhiteBalance)group.readEntry(d.OPTIONWHITEBALANCEENTRY,         (int)defaultPrm.whiteBalance);
+    prm.customWhiteBalance      = group.readEntry(d.OPTIONCUSTOMWHITEBALANCEENTRY,                                      defaultPrm.customWhiteBalance);
+    prm.customWhiteBalanceGreen = group.readEntry(d.OPTIONCUSTOMWBGREENENTRY,                                           defaultPrm.customWhiteBalanceGreen);
+    prm.RGBInterpolate4Colors   = group.readEntry(d.OPTIONFOURCOLORRGBENTRY,                                            defaultPrm.RGBInterpolate4Colors);
+    prm.unclipColors            = group.readEntry(d.OPTIONUNCLIPCOLORSENTRY,                                            defaultPrm.unclipColors);
+    prm.DontStretchPixels       = group.readEntry(d.OPTIONDONTSTRETCHPIXELSSENTRY,                                       defaultPrm.DontStretchPixels);
+    prm.NRType                  = (DRawDecoderSettings::NoiseReduction)group.readEntry(d.OPTIONNOISEREDUCTIONTYPEENTRY, (int)defaultPrm.NRType);
+    prm.brightness              = group.readEntry(d.OPTIONBRIGHTNESSMULTIPLIERENTRY,                                    defaultPrm.brightness);
+    prm.enableBlackPoint        = group.readEntry(d.OPTIONUSEBLACKPOINTENTRY,                                           defaultPrm.enableBlackPoint);
+    prm.blackPoint              = group.readEntry(d.OPTIONBLACKPOINTENTRY,                                              defaultPrm.blackPoint);
+    prm.enableWhitePoint        = group.readEntry(d.OPTIONUSEWHITEPOINTENTRY,                                           defaultPrm.enableWhitePoint);
+    prm.whitePoint              = group.readEntry(d.OPTIONWHITEPOINTENTRY,                                              defaultPrm.whitePoint);
+    prm.medianFilterPasses      = group.readEntry(d.OPTIONMEDIANFILTERPASSESENTRY,                                      defaultPrm.medianFilterPasses);
+    prm.NRThreshold             = group.readEntry(d.OPTIONNOISEREDUCTIONTHRESHOLDENTRY,                                 defaultPrm.NRThreshold);
+    prm.RAWQuality              = (DRawDecoderSettings::DecodingQuality)group.readEntry(d.OPTIONDECODINGQUALITYENTRY,   (int)defaultPrm.RAWQuality);
+    prm.outputColorSpace        = (DRawDecoderSettings::OutputColorSpace)group.readEntry(d.OPTIONOUTPUTCOLORSPACEENTRY, (int)defaultPrm.outputColorSpace);
+    prm.autoBrightness          = group.readEntry(d.OPTIONAUTOBRIGHTNESSENTRY,                                          defaultPrm.autoBrightness);
 
     //-- Extended demosaicing settings ----------------------------------------------------------
 
-    prm.dcbIterations           = group.readEntry(OPTIONDCBITERATIONSENTRY,                                           defaultPrm.dcbIterations);
-    prm.dcbEnhanceFl            = group.readEntry(OPTIONDCBENHANCEFLENTRY,                                            defaultPrm.dcbEnhanceFl);
-    prm.expoCorrection          = group.readEntry(OPTIONEXPOCORRECTIONENTRY,                                          defaultPrm.expoCorrection);
-    prm.expoCorrectionShift     = group.readEntry(OPTIONEXPOCORRECTIONSHIFTENTRY,                                     defaultPrm.expoCorrectionShift);
-    prm.expoCorrectionHighlight = group.readEntry(OPTIONEXPOCORRECTIONHIGHLIGHTENTRY,                                 defaultPrm.expoCorrectionHighlight);
+    prm.dcbIterations           = group.readEntry(d.OPTIONDCBITERATIONSENTRY,                                           defaultPrm.dcbIterations);
+    prm.dcbEnhanceFl            = group.readEntry(d.OPTIONDCBENHANCEFLENTRY,                                            defaultPrm.dcbEnhanceFl);
+    prm.expoCorrection          = group.readEntry(d.OPTIONEXPOCORRECTIONENTRY,                                          defaultPrm.expoCorrection);
+    prm.expoCorrectionShift     = group.readEntry(d.OPTIONEXPOCORRECTIONSHIFTENTRY,                                     defaultPrm.expoCorrectionShift);
+    prm.expoCorrectionHighlight = group.readEntry(d.OPTIONEXPOCORRECTIONHIGHLIGHTENTRY,                                 defaultPrm.expoCorrectionHighlight);
 }
 
 void DRawDecoderWidget::writeSettings(const DRawDecoderSettings& prm, KConfigGroup& group)
 {
-    group.writeEntry(OPTIONFIXCOLORSHIGHLIGHTSENTRY,     prm.fixColorsHighlights);
-    group.writeEntry(OPTIONDECODESIXTEENBITENTRY,        prm.sixteenBitsImage);
-    group.writeEntry(OPTIONWHITEBALANCEENTRY,            (int)prm.whiteBalance);
-    group.writeEntry(OPTIONCUSTOMWHITEBALANCEENTRY,      prm.customWhiteBalance);
-    group.writeEntry(OPTIONCUSTOMWBGREENENTRY,           prm.customWhiteBalanceGreen);
-    group.writeEntry(OPTIONFOURCOLORRGBENTRY,            prm.RGBInterpolate4Colors);
-    group.writeEntry(OPTIONUNCLIPCOLORSENTRY,            prm.unclipColors);
-    group.writeEntry(OPTIONDONTSTRETCHPIXELSSENTRY,       prm.DontStretchPixels);
-    group.writeEntry(OPTIONNOISEREDUCTIONTYPEENTRY,      (int)prm.NRType);
-    group.writeEntry(OPTIONBRIGHTNESSMULTIPLIERENTRY,    prm.brightness);
-    group.writeEntry(OPTIONUSEBLACKPOINTENTRY,           prm.enableBlackPoint);
-    group.writeEntry(OPTIONBLACKPOINTENTRY,              prm.blackPoint);
-    group.writeEntry(OPTIONUSEWHITEPOINTENTRY,           prm.enableWhitePoint);
-    group.writeEntry(OPTIONWHITEPOINTENTRY,              prm.whitePoint);
-    group.writeEntry(OPTIONMEDIANFILTERPASSESENTRY,      prm.medianFilterPasses);
-    group.writeEntry(OPTIONNOISEREDUCTIONTHRESHOLDENTRY, prm.NRThreshold);
-    group.writeEntry(OPTIONDECODINGQUALITYENTRY,         (int)prm.RAWQuality);
-    group.writeEntry(OPTIONOUTPUTCOLORSPACEENTRY,        (int)prm.outputColorSpace);
-    group.writeEntry(OPTIONAUTOBRIGHTNESSENTRY,          prm.autoBrightness);
+    Private d;
+
+    group.writeEntry(d.OPTIONFIXCOLORSHIGHLIGHTSENTRY,     prm.fixColorsHighlights);
+    group.writeEntry(d.OPTIONDECODESIXTEENBITENTRY,        prm.sixteenBitsImage);
+    group.writeEntry(d.OPTIONWHITEBALANCEENTRY,            (int)prm.whiteBalance);
+    group.writeEntry(d.OPTIONCUSTOMWHITEBALANCEENTRY,      prm.customWhiteBalance);
+    group.writeEntry(d.OPTIONCUSTOMWBGREENENTRY,           prm.customWhiteBalanceGreen);
+    group.writeEntry(d.OPTIONFOURCOLORRGBENTRY,            prm.RGBInterpolate4Colors);
+    group.writeEntry(d.OPTIONUNCLIPCOLORSENTRY,            prm.unclipColors);
+    group.writeEntry(d.OPTIONDONTSTRETCHPIXELSSENTRY,       prm.DontStretchPixels);
+    group.writeEntry(d.OPTIONNOISEREDUCTIONTYPEENTRY,      (int)prm.NRType);
+    group.writeEntry(d.OPTIONBRIGHTNESSMULTIPLIERENTRY,    prm.brightness);
+    group.writeEntry(d.OPTIONUSEBLACKPOINTENTRY,           prm.enableBlackPoint);
+    group.writeEntry(d.OPTIONBLACKPOINTENTRY,              prm.blackPoint);
+    group.writeEntry(d.OPTIONUSEWHITEPOINTENTRY,           prm.enableWhitePoint);
+    group.writeEntry(d.OPTIONWHITEPOINTENTRY,              prm.whitePoint);
+    group.writeEntry(d.OPTIONMEDIANFILTERPASSESENTRY,      prm.medianFilterPasses);
+    group.writeEntry(d.OPTIONNOISEREDUCTIONTHRESHOLDENTRY, prm.NRThreshold);
+    group.writeEntry(d.OPTIONDECODINGQUALITYENTRY,         (int)prm.RAWQuality);
+    group.writeEntry(d.OPTIONOUTPUTCOLORSPACEENTRY,        (int)prm.outputColorSpace);
+    group.writeEntry(d.OPTIONAUTOBRIGHTNESSENTRY,          prm.autoBrightness);
 
     //-- Extended demosaicing settings ----------------------------------------------------------
 
-    group.writeEntry(OPTIONDCBITERATIONSENTRY,           prm.dcbIterations);
-    group.writeEntry(OPTIONDCBENHANCEFLENTRY,            prm.dcbEnhanceFl);
-    group.writeEntry(OPTIONEXPOCORRECTIONENTRY,          prm.expoCorrection);
-    group.writeEntry(OPTIONEXPOCORRECTIONSHIFTENTRY,     prm.expoCorrectionShift);
-    group.writeEntry(OPTIONEXPOCORRECTIONHIGHLIGHTENTRY, prm.expoCorrectionHighlight);
+    group.writeEntry(d.OPTIONDCBITERATIONSENTRY,           prm.dcbIterations);
+    group.writeEntry(d.OPTIONDCBENHANCEFLENTRY,            prm.dcbEnhanceFl);
+    group.writeEntry(d.OPTIONEXPOCORRECTIONENTRY,          prm.expoCorrection);
+    group.writeEntry(d.OPTIONEXPOCORRECTIONSHIFTENTRY,     prm.expoCorrectionShift);
+    group.writeEntry(d.OPTIONEXPOCORRECTIONHIGHLIGHTENTRY, prm.expoCorrectionHighlight);
 }
 
 } // NameSpace Digikam
