@@ -6,7 +6,7 @@
  * Date        : 2008-12-10
  * Description : misc file operation methods
  *
- * SPDX-FileCopyrightText: 2014-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2014-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2006-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -159,7 +159,7 @@ void DFileOperations::openFilesWithDefaultApplication(const QList<QUrl>& urls)
 
 #endif
 
-    Q_FOREACH (const QUrl& url, urls)
+    for (const QUrl& url : std::as_const(urls))
     {
         QDesktopServices::openUrl(url);
     }
@@ -269,7 +269,7 @@ void DFileOperations::openInFileManager(const QList<QUrl>& urls)
     QUrl first   = urls.first();
     first        = first.adjusted(QUrl::RemoveFilename);
 
-    Q_FOREACH (const QUrl& url, urls)
+    for (const QUrl& url : std::as_const(urls))
     {
         if (first != url.adjusted(QUrl::RemoveFilename))
         {
@@ -290,6 +290,7 @@ void DFileOperations::openInFileManager(const QList<QUrl>& urls)
     }
 
     QString path = fileUrls.first().toLocalFile();
+    Q_UNUSED(path);
 
 #ifdef Q_OS_WIN
 
@@ -370,7 +371,7 @@ void DFileOperations::openInFileManager(const QList<QUrl>& urls)
     {
         QStringList uris;
 
-        Q_FOREACH (const QUrl& url, fileUrls)
+        for (const QUrl& url : std::as_const(fileUrls))
         {
             uris << url.toString();
         }
@@ -429,7 +430,9 @@ bool DFileOperations::copyFolderRecursively(const QString& srcPath,
         }
     }
 
-    Q_FOREACH (const QFileInfo& fileInfo, srcDir.entryInfoList(QDir::Files))
+    const auto list = srcDir.entryInfoList(QDir::Files);
+
+    for (const QFileInfo& fileInfo : list)
     {
         QString copyPath = newCopyPath + QLatin1Char('/') + fileInfo.fileName();
 
@@ -454,7 +457,9 @@ bool DFileOperations::copyFolderRecursively(const QString& srcPath,
         }
     }
 
-    Q_FOREACH (const QFileInfo& fileInfo, srcDir.entryInfoList(QDir::Dirs | QDir::NoDotAndDotDot))
+    const auto list2 = srcDir.entryInfoList(QDir::Dirs | QDir::NoDotAndDotDot);
+
+    for (const QFileInfo& fileInfo : list2)
     {
         if (!copyFolderRecursively(fileInfo.filePath(), newCopyPath, itemId, cancel, false))
         {   // cppcheck-suppress useStlAlgorithm
@@ -468,7 +473,7 @@ bool DFileOperations::copyFolderRecursively(const QString& srcPath,
 bool DFileOperations::copyFiles(const QStringList& srcPaths,
                                 const QString& dstPath)
 {
-    Q_FOREACH (const QString& path, srcPaths)
+    for (const QString& path : std::as_const(srcPaths))
     {
         QFileInfo fileInfo(path);
         QString copyPath = dstPath + QLatin1Char('/') + fileInfo.fileName();
@@ -595,6 +600,20 @@ bool DFileOperations::copyFile(const QString& srcFile,
     return ret;
 }
 
+bool DFileOperations::removeAndCopyFile(const QString& srcFile,
+                                        const QString& dstFile)
+{
+    if (QFile::exists(dstFile))
+    {
+        if (!QFile::remove(dstFile))
+        {
+            return false;
+        }
+    }
+
+    return copyFile(srcFile, dstFile);
+}
+
 bool DFileOperations::copyModificationTime(const QString& srcFile,
                                            const QString& dstFile)
 {
@@ -655,7 +674,8 @@ bool DFileOperations::setModificationTime(const QString& srcFile,
     return false;
 }
 
-QString DFileOperations::findExecutable(const QString& name)
+QString DFileOperations::findExecutable(const QString& name,
+                                        const QStringList& hints)
 {
     QString path;
     QString program = name;
@@ -711,7 +731,7 @@ QString DFileOperations::findExecutable(const QString& name)
 
 #endif
 
-    path = QStandardPaths::findExecutable(program);
+    path = QStandardPaths::findExecutable(program, hints);
 
     return path;
 }
@@ -726,7 +746,7 @@ bool DFileOperations::sidecarFiles(const QString& srcFile,
 
     QFileInfo srcInfo(srcFile);
 
-    Q_FOREACH (const QString& ext, sidecarExtensions)
+    for (const QString& ext : std::as_const(sidecarExtensions))
     {
         QString suffix(QLatin1Char('.') + ext);
 
