@@ -7,7 +7,7 @@
  * Description : Figure out camera clock delta from a clock picture.
  *
  * SPDX-FileCopyrightText: 2009      by Pieter Edelman <p dot edelman at gmx dot net>
- * SPDX-FileCopyrightText: 2011-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2011-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2014      by Michael G. Hansen <mike at mghansen dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -39,6 +39,7 @@
 
 // Local includes
 
+#include "digikam_globals.h"
 #include "dmetadata.h"
 #include "imagedialog.h"
 #include "timeadjustcontainer.h"
@@ -54,22 +55,16 @@ class Q_DECL_HIDDEN ClockPhotoDialog::Private
 
 public:
 
-    explicit Private()
-      : buttons       (nullptr),
-        calendar      (nullptr),
-        dtLabel       (nullptr),
-        previewManager(nullptr)
-    {
-    }
+    Private() = default;
 
     DeltaTime         deltaValues;
 
-    QDialogButtonBox* buttons;
-    QDateTimeEdit*    calendar;
+    QDialogButtonBox* buttons           = nullptr;
+    QDateTimeEdit*    calendar          = nullptr;
     QDateTime         photoDateTime;
-    QLabel*           dtLabel;
+    QLabel*           dtLabel           = nullptr;
 
-    GraphicsDImgView* previewManager;
+    GraphicsDImgView* previewManager    = nullptr;
 };
 
 ClockPhotoDialog::ClockPhotoDialog(QWidget* const parent, const QUrl& defaultUrl)
@@ -140,7 +135,6 @@ ClockPhotoDialog::ClockPhotoDialog(QWidget* const parent, const QUrl& defaultUrl
 
     // Show the window.
 
-    loadSettings();
     show();
 
     if (defaultUrl.isValid())
@@ -211,16 +205,18 @@ bool ClockPhotoDialog::setImage(const QUrl& imageFile)
 
 void ClockPhotoDialog::loadSettings()
 {
-    KConfigGroup group = KSharedConfig::openConfig()->group(QLatin1String("Clock Photo Dialog"));
+    KSharedConfig::Ptr config = KSharedConfig::openConfig();
+    KConfigGroup group        = config->group(QLatin1String("Clock Photo Dialog"));
 
-    winId();
     DXmlGuiWindow::restoreWindowSize(windowHandle(), group);
     resize(windowHandle()->size());
 }
 
 void ClockPhotoDialog::saveSettings()
 {
-    KConfigGroup group = KSharedConfig::openConfig()->group(QLatin1String("Clock Photo Dialog"));
+    KSharedConfig::Ptr config = KSharedConfig::openConfig();
+    KConfigGroup group        = config->group(QLatin1String("Clock Photo Dialog"));
+
     DXmlGuiWindow::saveWindowSize(windowHandle(), group);
 }
 
@@ -256,7 +252,7 @@ void ClockPhotoDialog::slotOk()
 
     // Determine the number of seconds between the dates.
 
-    int delta = d->photoDateTime.secsTo(d->calendar->dateTime());
+    int delta = d->photoDateTime.secsTo(asDateTimeUTC(d->calendar->dateTime()));
 
     // If the photo datetime is newer than the user datetime, it results in subtraction.
 
@@ -292,6 +288,13 @@ void ClockPhotoDialog::slotCancel()
     reject();
 }
 
+void ClockPhotoDialog::showEvent(QShowEvent* e)
+{
+    loadSettings();
+
+    QDialog::showEvent(e);
+}
+
 } // namespace Digikam
 
 #include "moc_clockphotodialog.cpp"
