@@ -6,14 +6,13 @@
  * Date        : 2010-02-20
  * Description : color selector widget
  *
- * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_DCOLOR_SELECTOR_H
-#define DIGIKAM_DCOLOR_SELECTOR_H
+#pragma once
 
 // Qt includes
 
@@ -37,7 +36,7 @@ class DIGIKAM_EXPORT DColorSelector : public QPushButton
 public:
 
     explicit DColorSelector(QWidget* const parent = nullptr);
-    ~DColorSelector() override;
+    ~DColorSelector()               override;
 
     void setColor(const QColor& color);
     QColor color() const;
@@ -54,14 +53,12 @@ private Q_SLOTS:
 
 private:
 
-    void paintEvent(QPaintEvent*) override;
+    void paintEvent(QPaintEvent*)   override;
 
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_DCOLOR_SELECTOR_H
