@@ -6,7 +6,7 @@
  * Date        : 2021-04-29
  * Description : ExifTool configuration panel.
  *
- * SPDX-FileCopyrightText: 2021-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2021-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -45,20 +45,15 @@ class Q_DECL_HIDDEN ExifToolConfPanel::Private
 {
 public:
 
-    explicit Private()
-      : exifToolBinWidget(nullptr),
-        searchBar        (nullptr),
-        exifToolFormats  (nullptr)
-    {
-    }
+    Private() = default;
 
 public:
 
-    DBinarySearch* exifToolBinWidget;
+    DBinarySearch* exifToolBinWidget = nullptr;
     ExifToolBinary exifToolBin;
-    SearchTextBar* searchBar;
+    SearchTextBar* searchBar         = nullptr;
 
-    QTreeWidget*   exifToolFormats;
+    QTreeWidget*   exifToolFormats   = nullptr;
 };
 
 // --------------------------------------------------------
@@ -122,7 +117,9 @@ ExifToolConfPanel::ExifToolConfPanel(QWidget* const parent)
     connect(d->exifToolBinWidget, SIGNAL(signalBinariesFound(bool)),
             this, SLOT(slotExifToolBinaryFound(bool)));
 
-    Q_FOREACH (const QString& path, MetaEngineSettings::instance()->settings().defaultExifToolSearchPaths())
+    const auto paths = MetaEngineSettings::instance()->settings().defaultExifToolSearchPaths();
+
+    for (const QString& path : paths)
     {
         d->exifToolBinWidget->addDirectory(path);
     }
@@ -199,8 +196,9 @@ void ExifToolConfPanel::slotExifToolBinaryFound(bool found)
 void ExifToolConfPanel::slotSearchTextChanged(const SearchTextSettings& settings)
 {
     bool query     = false;
-    int  results   = 0;
     QString search = settings.text.toLower();
+    int  results   = 0;
+    Q_UNUSED(results);
 
     QTreeWidgetItemIterator it(d->exifToolFormats);
 
