@@ -7,14 +7,13 @@
  * Description : a widget to display non standard Exif metadata
  *               used by camera makers
  *
- * SPDX-FileCopyrightText: 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_MAKER_NOTE_WIDGET_H
-#define DIGIKAM_MAKER_NOTE_WIDGET_H
+#pragma once
 
 // Local includes
 
@@ -32,7 +31,7 @@ public:
 
     explicit MakerNoteWidget(QWidget* const parent,
                              const QString& name = QString());
-    ~MakerNoteWidget()                              override;
+    ~MakerNoteWidget()                              override = default;
 
     bool loadFromURL(const QUrl& url)               override;
 
@@ -56,5 +55,3 @@ private:
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_MAKER_NOTE_WIDGET_H
