@@ -6,14 +6,13 @@
  * Date        : 2007-02-06
  * Description : setup RAW decoding settings.
  *
- * SPDX-FileCopyrightText: 2007-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2007-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef SHOW_FOTO_SETUP_RAW_H
-#define SHOW_FOTO_SETUP_RAW_H
+#pragma once
 
 // Qt includes
 
@@ -37,7 +36,7 @@ public:
 public:
 
     explicit ShowfotoSetupRaw(QWidget* const parent = nullptr);
-    ~ShowfotoSetupRaw() override;
+    ~ShowfotoSetupRaw()      override;
 
     void setActiveTab(RAWTab tab);
     RAWTab activeTab() const;
@@ -51,9 +50,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace ShowFoto
-
-#endif // SHOW_FOTO_SETUP_RAW_H
