@@ -8,14 +8,13 @@
  *
  * SPDX-FileCopyrightText: 2010      by Aditya Bhatt <adityabhatt1991 at gmail dot com>
  * SPDX-FileCopyrightText: 2010-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * SPDX-FileCopyrightText: 2012-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2012-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
 #include "facegroup_p.h"
-#include "assignnamewidget_p.h"
 
 namespace Digikam
 {
@@ -37,9 +36,8 @@ FaceGroup::FaceGroup(GraphicsDImgView* const view)
     connect(view->previewItem(), SIGNAL(stateChanged(int)),
             this, SLOT(itemStateChanged(int)));
 
-    d->editPipeline.plugDatabaseEditor();
-    d->editPipeline.plugTrainer();
-    d->editPipeline.construct();
+    connect(CoreDbAccess::databaseWatch(), SIGNAL(imageTagChange(ImageTagChangeset)),
+            this, SLOT(slotImageTagChange(ImageTagChangeset)));
 }
 
 FaceGroup::~FaceGroup()
@@ -52,7 +50,6 @@ void FaceGroup::itemStateChanged(int itemState)
     switch (itemState)
     {
         case DImgPreviewItem::NoImage:
-        case DImgPreviewItem::Loading:
         case DImgPreviewItem::ImageLoadingFailed:
         {
             d->visibilityController->hide();
@@ -91,7 +88,7 @@ QList<RegionFrameItem*> FaceGroup::items() const
 {
     QList<RegionFrameItem*> items;
 
-    Q_FOREACH (FaceItem* const item, d->items)
+    for (FaceItem* const item : std::as_const(d->items))
     {
         items << item;
     }
@@ -138,12 +135,11 @@ void FaceGroup::setVisibleItem(RegionFrameItem* item)
 
 void FaceGroup::setInfo(const ItemInfo& info)
 {
-    if ((d->info == info) && (d->state != NoFaces))
+    if (d->info != info)
     {
-        return;
+        clear();
     }
 
-    clear();
     d->info = info;
 
     if (d->visibilityController->shallBeShown())
@@ -160,19 +156,6 @@ void FaceGroup::aboutToSetInfo(const ItemInfo& info)
     }
 
     applyItemGeometryChanges();
-    clear();
-}
-
-void FaceGroup::aboutToSetInfoAfterRotate(const ItemInfo& info)
-{
-    if (d->info == info)
-    {
-        return;
-    }
-/*
-    applyItemGeometryChanges();
-*/
-    clear();
 }
 
 static QPointF closestPointOfRect(const QPointF& p, const QRectF& r)
@@ -206,14 +189,16 @@ RegionFrameItem* FaceGroup::closestItem(const QPointF& p, qreal* const manhattan
     qreal minDistance            = 0;
     qreal minCenterDistance      = 0;
 
-    Q_FOREACH (RegionFrameItem* const item, d->items)
+    for (RegionFrameItem* const item : std::as_const(d->items))
     {
         QRectF r       = item->boundingRect().translated(item->pos());
         qreal distance = (p - closestPointOfRect(p, r)).manhattanLength();
 
-        if (!closestItem             ||
+        if (
+            !closestItem             ||
             (distance < minDistance) ||
-            ((distance == 0) && (p - r.center()).manhattanLength() < minCenterDistance))
+            ((distance == 0) && (p - r.center()).manhattanLength() < minCenterDistance)
+           )
         {
             closestItem = item;
             minDistance = distance;
@@ -248,26 +233,27 @@ void FaceGroup::itemHoverMoveEvent(QGraphicsSceneHoverEvent* e)
         // There's a possible nuisance when the direct mouse way from hovering pos to HUD widget
         // is not part of the condition. Maybe, we should add a exemption for this case.
 
-        if (distance < 25)
+        if (distance < d->MaxMouseDistance)
         {
             setVisibleItem(item);
         }
         else
         {
-            // get all items close to pos
+            // Get all items close to pos.
 
             QList<QGraphicsItem*> hItems = d->hotItems(e->scenePos());
 
-            // this will be the one item shown by mouse over
+            // This will be the one item shown by mouse over.
 
             QList<QObject*> visible      = d->visibilityController->visibleItems(ItemVisibilityController::ExcludeFadingOut);
 
-            Q_FOREACH (QGraphicsItem* const item2, hItems)
+            for (QGraphicsItem* const item2 : std::as_const(hItems))
             {
-                Q_FOREACH (QObject* const parent, visible)
+                for (QObject* const parent : std::as_const(visible))
                 {
                     if (static_cast<QGraphicsObject*>(parent)->isAncestorOf(item2))
-                    {   // cppcheck-suppress useStlAlgorithm
+                    {
+                        // cppcheck-suppress useStlAlgorithm
                         return;
                     }
                 }
@@ -300,7 +286,7 @@ void FaceGroup::enterEvent(QEvent*)
 
 bool FaceGroup::hasUnconfirmed()
 {
-    Q_FOREACH (FaceItem* const item, d->items)
+    for (FaceItem* const item : std::as_const(d->items))
     {
         if (item->face().isUnconfirmedType())
         {
@@ -313,27 +299,23 @@ bool FaceGroup::hasUnconfirmed()
 
 void FaceGroup::load()
 {
-    if (d->state != NoFaces)
-    {
-        return;
-    }
-
-    d->state      = LoadingFaces;
-    d->exifRotate = (MetaEngineSettings::instance()->settings().exifRotate            ||
-                     ((d->view->previewItem()->image().detectedFormat() == DImg::RAW) &&
-                      !d->view->previewItem()->image().attribute(QLatin1String("fromRawEmbeddedPreview")).toBool()));
+    d->exifRotate = (
+                        MetaEngineSettings::instance()->settings().exifRotate            ||
+                        ((d->view->previewItem()->image().detectedFormat() == DImg::RAW) &&
+                         !d->view->previewItem()->image().attribute(QLatin1String("fromRawEmbeddedPreview")).toBool())
+                    );
 
     if (d->info.isNull())
     {
-        d->state = FacesLoaded;
+        clear();
 
         return;
     }
 
-    QList<FaceTagsIface> faces = FaceTagsEditor().databaseFaces(d->info.id());
-    d->visibilityController->clear();
+    const QList<FaceTagsIface> faces = FaceTagsEditor().databaseFaces(d->info.id());
+    clear();
 
-    Q_FOREACH (const FaceTagsIface& face, faces)
+    for (const FaceTagsIface& face : faces)
     {
         d->addItem(face);
     }
@@ -345,7 +327,7 @@ void FaceGroup::load()
         d->visibilityController->show();
     }
 
-    // See bug 408982
+    // See bug 408982.
 
     if (d->visibilityController->hasVisibleItems())
     {
@@ -355,10 +337,10 @@ void FaceGroup::load()
 
 void FaceGroup::clear()
 {
-    cancelAddItem();
+    slotCancelAddItem();
     d->visibilityController->clear();
 
-    Q_FOREACH (FaceItem* const item, d->items)
+    for (FaceItem* const item : std::as_const(d->items))
     {
         delete item;
     }
@@ -375,15 +357,17 @@ void FaceGroup::rejectAll()
 
 void FaceGroup::markAllAsIgnored()
 {
-    Q_FOREACH (FaceItem* const item, d->items)
+    for (FaceItem* const item : std::as_const(d->items))
     {
-        if (item->face().isUnknownName()   ||
-            item->face().isUnconfirmedName())
+        if (
+            item->face().isUnknownName()   ||
+            item->face().isUnconfirmedName()
+           )
         {
-            FaceTagsIface face = d->editPipeline.editTag(d->info, item->face(),
-                                                         FaceTags::ignoredPersonTagId());
-
+            FaceTagsIface face = d->newEditPipeline->editTag(d->info, item->face(),
+                                                             FaceTags::ignoredPersonTagId());
             item->setFace(face);
+
             item->switchMode(AssignNameWidget::IgnoredMode);
         }
     }
@@ -401,7 +385,6 @@ void FaceGroup::slotAlbumsUpdated(int type)
         return;
     }
 
-    clear();
     load();
 }
 
@@ -412,41 +395,75 @@ void FaceGroup::slotAlbumRenamed(Album* album)
         return;
     }
 
-    Q_FOREACH (FaceItem* const item, d->items)
+    for (FaceItem* const item : std::as_const(d->items))
     {
-        if (!item->face().isNull() &&
-            (item->face().tagId() == album->id()))
+        if (
+            !item->face().isNull() &&
+            (item->face().tagId() == album->id())
+           )
         {
             item->updateCurrentTag();
         }
     }
 }
 
-void FaceGroup::slotAssigned(const TaggingAction& action, const ItemInfo&, const QVariant& faceIdentifier)
+void FaceGroup::slotImageTagChange(const ImageTagChangeset& changeset)
 {
-   QList<QVariant> faceList(faceIdentifier.toList());
-
-    if (faceList.size() != 5)
+    if (!changeset.containsImage(d->info.id()))
     {
         return;
     }
 
-    FaceItem* const item    = d->items[faceList[4].toInt()];
-    FaceTagsIface face      = item->face();
-    TagRegion currentRegion(item->originalRect());
+    if (changeset.operation() == ImageTagChangeset::PropertiesChanged)
+    {
+        if (
+            changeset.containsTag(FaceTags::unknownPersonTagId())  ||
+            changeset.containsTag(FaceTags::unconfirmedPersonTagId())
+           )
+        {
+            load();
+        }
+    }
+}
+
+void FaceGroup::slotAssigned(const TaggingAction& action, const ItemInfo&, const QVariant& faceIdentifier)
+{
+    QList<QVariant> faceList(faceIdentifier.toList());
+
+    if (faceList.size() != d->MaxFaceListSize)
+    {
+        return;
+    }
+
+    FaceItem* const item = d->items[faceList[4].toInt()];
+    FaceTagsIface face   = item->face();
+    QRect faceRect       = item->originalRect();
+
+    if (!d->exifRotate)
+    {
+        TagRegion::adjustToOrientation(faceRect,
+                                       d->info.orientation(),
+                                       d->info.dimensions());
+    }
+
+    TagRegion currentRegion(faceRect);
 
     if (
-            !face.isConfirmedName()          ||
-            (face.region() != currentRegion) ||
-            action.shallCreateNewTag()       ||
-            (
-                 action.shallAssignTag() &&
-                 (action.tagId() != face.tagId())
-            )
+        !face.isConfirmedName()          ||
+        (face.region() != currentRegion) ||
+        action.shallCreateNewTag()       ||
+        (
+            action.shallAssignTag() &&
+            (action.tagId() != face.tagId())
+        )
        )
     {
         int tagId = 0;
 
+        // Apply a modified region.
+
+        face.setRegion(currentRegion);
+
         if      (action.shallAssignTag())
         {
             tagId = action.tagId();
@@ -455,11 +472,12 @@ void FaceGroup::slotAssigned(const TaggingAction& action, const ItemInfo&, const
         {
             QStringList faceNames = action.newTagName().split(QLatin1Char('/'),
                                                               Qt::SkipEmptyParts);
+
             if (!faceNames.isEmpty())
             {
-                tagId             = action.parentTagId();
+                tagId = action.parentTagId();
 
-                Q_FOREACH (const QString& name, faceNames)
+                for (const QString& name : std::as_const(faceNames))
                 {
                     tagId = FaceTags::getOrCreateTagForPerson(name.trimmed(), tagId);
                 }
@@ -478,25 +496,24 @@ void FaceGroup::slotAssigned(const TaggingAction& action, const ItemInfo&, const
             return;
         }
 
-        face = d->editPipeline.confirm(d->info, face, d->view->previewItem()->image(), tagId, currentRegion);
+        face = d->newEditPipeline->confirmFace(d->info, face, tagId, true);
+        item->setFace(face);
+
+        item->switchMode(AssignNameWidget::ConfirmedMode);
+
+        QTimer::singleShot(250, this, SLOT(slotFocusRandomFace()));
     }
-
-    item->setFace(face);
-    item->switchMode(AssignNameWidget::ConfirmedMode);
-
-    focusRandomFace();
 }
 
-void FaceGroup::focusRandomFace()
+void FaceGroup::slotFocusRandomFace()
 {
-    Q_FOREACH (FaceItem* const item, d->items)
+    for (FaceItem* const item : std::as_const(d->items))
     {
-        FaceTagsIface face = item->face();
-        AddTagsComboBox* comboBox = item->widget()->comboBox();
+        FaceTagsIface face              = item->face();
+        AddTagsComboBox* const comboBox = item->widget()->comboBox();
 
         if ((comboBox) && (!face.isConfirmedName()))
         {
-            comboBox->lineEdit()->selectAll();
             comboBox->lineEdit()->setFocus();
 
             return;
@@ -508,15 +525,15 @@ void FaceGroup::slotRejected(const ItemInfo&, const QVariant& faceIdentifier)
 {
     QList<QVariant> faceList(faceIdentifier.toList());
 
-    if (faceList.size() == 5)
+    if (faceList.size() == d->MaxFaceListSize)
     {
         FaceItem* const item = d->items[faceList[4].toInt()];
-        d->editPipeline.remove(d->info, item->face());
+        d->newEditPipeline->removeFace(d->info, item->face());
 
         item->setFace(FaceTagsIface());
         d->visibilityController->hideAndRemoveItem(item);
 
-        focusRandomFace();
+        QTimer::singleShot(250, this, SLOT(slotFocusRandomFace()));
     }
 }
 
@@ -524,7 +541,7 @@ void FaceGroup::slotIgnored(const ItemInfo&, const QVariant& faceIdentifier)
 {
     QList<QVariant> faceList(faceIdentifier.toList());
 
-    if (faceList.size() == 5)
+    if (faceList.size() == d->MaxFaceListSize)
     {
         FaceItem* const item = d->items[faceList[4].toInt()];
         QRect faceRect       = item->originalRect();
@@ -548,17 +565,15 @@ void FaceGroup::slotIgnored(const ItemInfo&, const QVariant& faceIdentifier)
                 preview.rotateAndFlip(d->info.orientation());
             }
 
-            face = d->editPipeline.editRegion(d->info, preview,
-                                              face, currentRegion);
+            face = d->newEditPipeline->editRegion(d->info, face, currentRegion, preview, false);
         }
 
-        face = d->editPipeline.editTag(d->info, face,
-                                       FaceTags::ignoredPersonTagId());
-
+        face = d->newEditPipeline->editTag(d->info, face,
+                                           FaceTags::ignoredPersonTagId());
         item->setFace(face);
         item->switchMode(AssignNameWidget::IgnoredMode);
 
-        focusRandomFace();
+        QTimer::singleShot(250, this, SLOT(slotFocusRandomFace()));
     }
 }
 
@@ -566,7 +581,7 @@ void FaceGroup::slotLabelClicked(const ItemInfo&, const QVariant& faceIdentifier
 {
     QList<QVariant> faceList(faceIdentifier.toList());
 
-    if (faceList.size() == 5)
+    if (faceList.size() == d->MaxFaceListSize)
     {
         FaceItem* const item = d->items[faceList[4].toInt()];
         item->switchMode(AssignNameWidget::ConfirmedEditMode);
@@ -577,7 +592,7 @@ void FaceGroup::slotIgnoredClicked(const ItemInfo&, const QVariant& faceIdentifi
 {
     QList<QVariant> faceList(faceIdentifier.toList());
 
-    if (faceList.size() == 5)
+    if (faceList.size() == d->MaxFaceListSize)
     {
         FaceItem* const item = d->items[faceList[4].toInt()];
         item->switchMode(AssignNameWidget::UnconfirmedEditMode);
@@ -613,7 +628,7 @@ void FaceGroup::addFace()
             this, SLOT(slotAddItemFinished(QRectF)));
 
     connect(d->manuallyAddWrapItem, SIGNAL(cancelled()),
-            this, SLOT(cancelAddItem()));
+            this, SLOT(slotCancelAddItem()));
 }
 
 void FaceGroup::slotAddItemStarted(const QPointF& pos)
@@ -650,19 +665,20 @@ void FaceGroup::slotAddItemFinished(const QRectF& rect)
         }
 
         TagRegion addRegion(faceRect);
-        FaceTagsIface face   = d->editPipeline.addManually(d->info,
-                                                           preview,
-                                                           addRegion);
+        FaceTagsIface face   = d->newEditPipeline->addManually(d->info,
+                                                               preview,
+                                                               addRegion,
+                                                               false);
         FaceItem* const item = d->addItem(face);
         d->visibilityController->setItemDirectlyVisible(item, true);
         item->switchMode(AssignNameWidget::UnconfirmedEditMode);
         d->manuallyAddWrapItem->stackBefore(item);
     }
 
-    cancelAddItem();
+    slotCancelAddItem();
 }
 
-void FaceGroup::cancelAddItem()
+void FaceGroup::slotCancelAddItem()
 {
     delete d->manuallyAddedItem;
     d->manuallyAddedItem = nullptr;
@@ -689,7 +705,7 @@ void FaceGroup::applyItemGeometryChanges()
         preview.rotateAndFlip(d->info.orientation());
     }
 
-    Q_FOREACH (FaceItem* const item, d->items)
+    for (FaceItem* const item : std::as_const(d->items))
     {
         if (item->face().isNull())
         {
@@ -709,10 +725,11 @@ void FaceGroup::applyItemGeometryChanges()
 
         if (item->face().region() != currentRegion)
         {
-            d->editPipeline.editRegion(d->info,
-                                       preview,
-                                       item->face(),
-                                       currentRegion);
+            d->newEditPipeline->editRegion(d->info,
+                                           item->face(),
+                                           currentRegion,
+                                           preview,
+                                           false);
         }
     }
 }
@@ -722,7 +739,7 @@ void ItemPreviewView::trainFaces()
 {
     QList<Face> trainList;
 
-    Q_FOREACH (Face f, d->currentFaces)
+    for (Face f : std::as_const(d->currentFaces))
     {
         if (f.name() != "" && !d->faceIface->isFaceTrained(getItemInfo().id(), f.toRect(), f.name()))
         {
@@ -741,18 +758,18 @@ void ItemPreviewView::trainFaces()
 
 void ItemPreviewView::suggestFaces()
 {
-    // Assign tentative names to the face list
+    // Assign tentative names to the face list.
 
     QList<Face> recogList;
 
-    Q_FOREACH (Face f, d->currentFaces)
+    for (Face f : std::as_const(d->currentFaces))
     {
         if (!d->faceIface->isFaceRecognized(getItemInfo().id(), f.toRect(), f.name()) && f.name().isEmpty())
         {
             f.setName(d->faceIface->recognizedName(f));
             d->faceIface->markFaceAsRecognized(getItemInfo().id(), f.toRect(), f.name());
 
-            // If the face wasn't recognized (too distant) don't suggest anything
+            // If the face wasn't recognized (too distant) don't suggest anything.
 
             if (f.name().isEmpty())
             {
@@ -768,7 +785,7 @@ void ItemPreviewView::suggestFaces()
     qCDebug(DIGIKAM_GENERAL_LOG) << "Number of suggestions = " << recogList.size();
     qCDebug(DIGIKAM_GENERAL_LOG) << "Number of faceitems = " << d->faceitems.size();
 
-    // Now find the relevant face items and suggest faces
+    // Now find the relevant face items and suggest faces.
 
     for (int i = 0 ; i < recogList.size() ; ++i)
     {
