@@ -6,14 +6,13 @@
  * Date        : 2009-28-04
  * Description : first run assistant dialog
  *
- * SPDX-FileCopyrightText: 2009-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_OPEN_FILE_PAGE_H
-#define DIGIKAM_OPEN_FILE_PAGE_H
+#pragma once
 
 // Local includes
 
@@ -36,9 +35,7 @@ public:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_OPEN_FILE_PAGE_H
