@@ -8,7 +8,7 @@
  *               (c) 2007-2022 Marble Team
  *               https://invent.kde.org/education/marble/-/raw/master/data/credits_authors.html
  *
- * SPDX-FileCopyrightText: 2023-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2023-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
  *
@@ -74,7 +74,7 @@ GeoDataVec2::Unit GeoDataVec2Private::parseUnits(const QString& value)
         return GeoDataVec2::InsetPixels;
     }
 
-    qCDebug(DIGIKAM_MARBLE_LOG) << "Warning: Unknown units value " << value << " - falling back to default 'fraction'";
+    qCDebug(DIGIKAM_GEOENGINE_LOG) << "Warning: Unknown units value " << value << " - falling back to default 'fraction'";
     return GeoDataVec2::Fraction;
 }
 
