@@ -6,7 +6,7 @@
 #
 # SPDX-FileCopyrightText: 2021      by TRAN Quoc Hung <quochungtran1999 at gmail dot com>
 # SPDX-FileCopyrightText: 2021      by Surya K M      <suryakm_is20 dot rvitm@rvei dot edu dot in>
-# SPDX-FileCopyrightText: 2021-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+# SPDX-FileCopyrightText: 2021-2025 by Gilles Caulier <caulier dot gilles at gmail dot com>
 # SPDX-FileCopyrightText: 2024      by Joerg Lohse    <joergmlpts at gmail dot com>
 
 #
@@ -239,6 +239,7 @@ optional_packages=("ruby"                               # For i18n extraction
                    "libclang-dev"                       # For static analysis
                    "doxygen"                            # For API doc
                    "graphviz"                           # For API doc
+                   "texlive-full"                       # For API doc
                    "kate"                               # For debuging
                    "ktexteditor-katepart"               # For debuging
                    "ccache"                             # For compiling
@@ -300,55 +301,10 @@ for pkg in ${optional_packages[@]}; do
     echo "-------------------------------------------------------------------"
 done
 
-# Remove native Qt6 libs from the system
-
-sudo apt remove -y libqt6core
-
-
 # Add symbolic links for Krazy static analyzer
 
 sudo ln -sf /usr/share/java              /opt/saxon
 sudo ln -sf /usr/share/java/Saxon-HE.jar /usr/share/java/saxon9he.jar
 
-echo "Remove SNAP and install Native Firefox package"
-echo "-------------------------------------------------------------------"
 
-sudo snap list
-sudo systemctl disable snapd.service
-sudo systemctl disable snapd.socket
-sudo systemctl disable snapd.seeded.service
 
-sudo snap remove firefox
-sudo snap remove thunderbird
-sudo snap remove snap-store
-sudo snap remove gtk-common-themes
-
-sudo snap remove gnome-3-38-2004
-sudo snap remove gnome-32-2204
-sudo snap remove gnome-42-2204
-sudo snap remove core20
-sudo snap remove core22
-sudo snap remove bare
-sudo snap remove snapd
-sudo snap remove snapd-desktop-integration
-
-sudo rm -rf /var/cache/snapd/
-sudo apt autoremove --purge snapd
-rm -rf ~/snap
-
-sudo tee /etc/apt/preferences.d/firefox-no-snap << EOF
-Package: firefox*
-Pin: release o=Ubuntu*
-Pin-Priority: -1
-EOF
-
-sudo apt install software-properties-common
-sudo add-apt-repository ppa:mozillateam/ppa
-
-sudo apt install firefox
-
-# Reinstall Plasma Discover without snapd dependency for the system update notifications.
-
-sudo apt install plasma-discover snapd-
-sudo apt --fix-broken install
-sudo apt install plasma-discover-notifier
